@@ -56,6 +56,19 @@
 //  #define SEND_RECV_BUG
 //  #define MIME_BASE64_BUG
 
+  struct th_str {
+    pthread_t t1;
+    pthread_t t2;
+    pthread_mutex_t read_mutex;
+    int th_sk; 
+    int th_timeout;
+    int th_out;
+    int th_stat;
+    int th_ret;
+    char th_cha[64];
+    };
+
+
 
   /* ---- bufer ---- */
   int mem_count(char [], char);
@@ -68,10 +81,14 @@
   int set_mem(char [], char, int);
   int rm_crlf(char [], int);
   int swap_mem(char [], char, char);
+  int swap_armem(char [], char, char, int, int);
   int chmem(char [], int);
   int self_memcpy(char *, char *, int);
   int self_strncat(char *, char *, int);
   int self_delim_get(char *, char *, char, int, int);
+  char * delim_f(char * base, char * backdata, char deli, int count);
+  char * delim_r(char * base, char * backdata, char deli, int count);
+
   int count_memcpy(char *, char *, int);
   char * count_memcpy2(char *, char *, int, int);
   int delim_count(char *, char, int, int *, int *);
@@ -106,9 +123,11 @@
   /* --- socket --- */
   int socket_reada(int, char *, int);
   int socket_readas(int, char *, int, int, int);
+  int socket_readasth(int sk, char * readdata, int max, int interval, int mode);
   int socket_reads(int, char * , int, int);
   int socket_sends(int, char *, int, char);
   int socket_send(int, char *, int);
+  int socket_send2(int, char *, int, int *);
   char * select_fdcat(int sk, char * getdata, int * ret, int max, int interval);
 
   /* --- file --- */
@@ -135,6 +154,7 @@
   int month_last(int, int);
   int month_minus(int);
   char * time_getr(char *);
+  double gettimeofday_se(void);
   char * message_id(char * backdata, char * name, char * domain);
 
   /* --- socket --- */
@@ -142,11 +162,15 @@
   char * socket_accept46(char * ipdate, fd_set rfd, int * s, int smax, int sockmax, int * sk, int * net);
   int socket_accept46rfd(fd_set * rfd, int * s, int smax);
   int socket_connect46(struct addrinfo * hints, char * ip, char * port, int * sk);
+  int socket_connect46select(struct addrinfo * hints, char * ip, char * port, int * sk, int timeout);
 
   int socket_connect(struct sockaddr_in *, int, char [], int *);
   int socket_bind(struct sockaddr_in *, int, char *, int *);
   int socket_accept(struct sockaddr_in *, int *, int *);
 
+// int select_connect(int *, struct sockaddr_in *, int, int);
+  int select_connect(int *, struct sockaddr_in *, int);
+
   /* --- thread --- */
   #include<pthread.h>
   int safe_pthread_mutex_lock(pthread_mutex_t *);
