@@ -9,7 +9,7 @@ int buk;
 int count;
 int inMax = strlen(chData);
 
-buk = 0;
+buk = -1;
 for(count = 0; count < inMax; count++){
    if(chData[count] == chA){
       buk=count;
