@@ -39,7 +39,7 @@ while(1){
       memset(cha, 0x00, 64);
       ret = ret + stat;
       if(ret > max - 63){
-         fprintf(stderr, "socket_reada(): read size err.\n");
+         fprintf(stderr, "socket_reada(): read size err. max=%d\n", max);
          break;
          }
       }
