@@ -12,6 +12,7 @@ int main(void)
 {
 int ret, sta, sto;
 char * taro = (char *)calloc(12, sizeof(char));
+char * taro2 = (char *)calloc(12, sizeof(char));
 char * hana = (char *)calloc(12, sizeof(char));
 char * sachi = (char *)calloc(12, sizeof(char));
 
@@ -129,7 +130,27 @@ ret = rm_char(taro, '0');
 printf("taro 2: <%s>%d\n\n", taro, ret);
 
 printf("count(): <%d>\n", counts("/tmp/hage", 1, 3));
-printf("count(): <%d>\n", counts("/etc/hage", 1, 3));
+
+taro = safe_memcpy(taro, "aaa,bbb,ccc,ddd,", 1000);
+taro2 = delim_f(taro, taro2, ',', 2);
+printf("delim_f(): %s  <%s>\n", taro, taro2);
+
+taro = safe_memcpy(taro, "aaa,bbb,ccc,ddd,", 1000);
+taro2 = delim_r(taro, taro2, ',', 4);
+printf("delim_r(): %s <%s>\n", taro, taro2);
+
+taro = safe_memcpy(taro, "aaa,bbb,ccc,ddd", 1000);
+taro2 = delim_r(taro, taro2, ',', 0);
+printf("delim_r(): %s <%s>\n", taro, taro2);
+
+printf("mem_tcount(): %d\n", mem_tcount("012345678", '1'));
+
+// taro = safe_memcpy(taro, "000:110:002:003:004", 128);
+taro = safe_memcpy(taro, "0:0", 128);
+printf("==1==%s==\n", taro);
+swap_armem(taro, ':', '-', 3, 7);
+printf("==2==%s==\n", taro);
+
 
 
 return 0;
