@@ -362,9 +362,18 @@ while($s < $num){
    elseif(0 == strcmp($MAILSEND, "MID")){
       $pcol2 = "bgcolor=magenta";
       }
+   elseif(0 == strcmp($MAILSEND, "AID")){
+      $pcol2 = "bgcolor=blue";
+      }
    elseif(0 == strcmp($MAILSEND, "MIX")){
       $pcol2 = "bgcolor=yellow";
       }
+   elseif(0 == strcmp($MAILSEND, "AIX")){
+      $pcol2 = "bgcolor=green";
+      }
+   elseif(0 == strcmp($MAILSEND, "DDX")){
+      $pcol2 = "bgcolor=pink";
+      }
    else{
       $pcol2 = $acol1;
       }
@@ -421,7 +430,10 @@ echo "<option value='' selected>Խʤ";
 echo "<option value=OFF>(OFF)";
 echo "<option value=ON>(ON)";
 echo "<option value=MID>(MID)ַ⡼ɣ";
+echo "<option value=AID>(AID)ַ⡼2᡼";
 echo "<option value=MIX>(MIX)ַ⡼ɣ";
+echo "<option value=AIX>(AIX)ַ⡼1᡼";
+echo "<option value=DDX>(DDX)ַ硢11 ";
 echo "</select>";
 echo "</td>";
 
