@@ -581,7 +581,10 @@ echo "<option value=$MAILSEND selected>$MAILSEND";
 echo "<option value=OFF>(OFF)";
 echo "<option value=ON>(ON)";
 echo "<option value=MID>(MID)ưַ⡼ɣ";
+echo "<option value=AID>(AID)ưַ⡼ɣ᡼";
 echo "<option value=MIX>(MIX)ưַ⡼ɣ";
+echo "<option value=AIX>(AIX)ưַ⡼ɣ᡼";
+echo "<option value=DDX>(DDX)ַ硢11 ";
 echo "</select><br>";
 echo "᡼߽ޤ <br>";
 echo "ưַ⡼ɤȤϡϢ³顼3ޤǥ᡼ޤʸߤޤ <br>";
