@@ -195,6 +195,7 @@ echo "<td $kcal1><font size=1>ƻ°</font></td>";
 echo "<td $kcal1><font size=1>Info & command & Protocol</font></td>";
 echo "<td $kcal1><font size=1>ƻ륯饤</font></td>";
 echo "<td $kcal1><font size=1>ƻ֥å̾</font></td>";
+echo "<td $kcal1><font size=1>ƻID</font></td>";
 echo "</tr>"; 
 
 echo "<tr>"; 
@@ -205,6 +206,7 @@ echo "<td $kcal2><font size=1>顼ܺɽ</font></td>";
 echo "<td $kcal2><font size=1>֥å饤</font></td>";
 echo "<td $kcal2><font size=1>ĥ꡼ʥ饤ñ̡</font></td>";
 echo "<td $kcal2><font size=1></font>ĥ꡼ʥ֥åñ̡</td>";
+echo "<td $kcal2><font size=1></font>ưǧ</td>";
 echo "</tr>"; 
 
 
@@ -274,6 +276,7 @@ while($s < $num){
       echo "<td $acol2>$ERRDATA</td>";
       echo "<td $ncol1><a target=_view href=$treewatch?CNAME=$CNAME>$CNAME</a></td>";
       echo "<td $acol2>$FREE4</td>";
+      echo "<td $acol1>$FREE3</td>";
       }
 
    elseif(0 == strcmp($MONITOR, "CLOSE")){
@@ -284,6 +287,7 @@ while($s < $num){
       echo "<td $bcol2>$ERRDATA</td>";
       echo "<td $ncol1><a target=_view href=$treewatch?CNAME=$CNAME>$CNAME</a></td>";
       echo "<td $bcol2>$FREE4</td>";
+      echo "<td $acol1>$FREE3</td>";
       }
 
 
@@ -302,18 +306,19 @@ while($s < $num){
             }
          echo "<td $ncol1><a target=_view href=$treewatch?CNAME=$CNAME&UNO=$FREE3#CENTER>$CNAME</a></td>";
          echo "<td $ncol2><a target=_view href=$treewatch?CNAME=$CNAME&BNAME=$FREE4&UNO=$FREE3#CENTER>$FREE4</a></td>";
+         echo "<td $ncol2><a target=check href=$monitorcheck?UNO=$FREE3&STATUS+UPDATE>$FREE3</a></td>";
          }
       elseif(0 == strcmp($MONITOR, "SNMP")){
          echo "<td $ncol2><a terget=edit href=$menucnew?CNAME=$CNAME&BNAME=$FREE4>$FREE1</a></td>";
-//       echo "<td $ncol2>$FREE1</td>";
          echo "<td $ncol1><a target=_view href=$treewatch?CNAME=$CNAME&UNO=$FREE3#CENTER>$CNAME</a></td>";
          echo "<td $ncol2><a target=_view href=$treewatch?CNAME=$CNAME&BNAME=$FREE4&UNO=$FREE3#CENTER>$FREE4</a></td>";
+         echo "<td $ncol2><a target=check href=$monitorcheck?UNO=$FREE3&STATUS+UPDATE>$FREE3</a></td>";
          }
       else{
          echo "<td $ncol2><a terget=edit href=$menucnew?CNAME=$CNAME&BNAME=$FREE4>$COM</a></td>";
-//       echo "<td $ncol2>$COM</td>";
          echo "<td $ncol1><a target=_view href=$treewatch?CNAME=$CNAME&UNO=$FREE3#CENTER>$CNAME</a></td>";
          echo "<td $ncol2><a target=_view href=$treewatch?CNAME=$CNAME&BNAME=$FREE4&UNO=$FREE3#CENTER>$FREE4</a></td>";
+         echo "<td $ncol2>$FREE3</td>";
          }
 
       }
