@@ -53,7 +53,7 @@ print(date("Y m d g i s A"));
 print("\n");
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -65,13 +65,13 @@ if(0 == strlen($select_data)){
    exit;
    }
 else{
-   $result = pg_query($conn, "$select_data");
+   $result = db_query($conn, "$select_data");
    print("顼κǤ\n");
    if(!$result){
       print("NG bud query $select_data\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num < 0){
       print("NG 顼κʤǤ\n");
       exit;
@@ -82,8 +82,8 @@ else{
 print("OK DBѹϴλޤ\n");
 printf("եȿǤƤޤ\n");
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 
