@@ -223,11 +223,18 @@ echo "ץȥ";
 echo "<select size=1 name=PROTO>";
 echo "<option value=>̤";
 print("<option value=ICMP>ICMP̳ǧ");
+print("<option value=V6ICMP>V6ICMP̳ǧ");
 print("<option value=ICMP2>ICMP̳ǧܺ");
 print("<option value=TRAC>ȥ졼ICMP");
 print("<option value=UDP>UDPݡ");
 print("<option value=TCP>TCPݡ");
+print("<option value=TCP6>TCP6ݡ");
 print("<option value=URL>URL status");
+print("<option value=URL6>URL6 status");
+print("<option value=GET>GET status");
+print("<option value=GET6>GET6 status");
+print("<option value=DEF>DEF status");
+print("<option value=DEF6>DEF6 status");
 print("<option value=SMTP>SMTP status");
 print("<option value=FTP>FTP status");
 print("<option value=POP>POP status");
