@@ -128,6 +128,9 @@ echo "</select>";
 print("<input type=submit value='饤Ⱥ'>");
 print("</form>");
 
+
+
+
 print("<br><br>");
 
 print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
@@ -138,7 +141,6 @@ print("֥åδƻܤƾäޤΤǤա<br>");
 print("Υܥ򲡤ȺڡӤޤ<br>");
 print("</font>");
 print("֥å̾");
-// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
 echo "<select size=1 name=BNAME>";
 echo "<option value='$BNAME'>$BNAME";
 for($select_count = 0; $select_count < $bname_count; $select_count++){
@@ -149,6 +151,42 @@ echo "</select>";
 print("<input type=submit value='֥å'>");
 print("</form>");
 
+
+
+
+print("<br><br>");
+
+print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
+print("<tr><td><font color=red size=3>");
+print("</td></tr>");
+print("֥åʣޤ <br>");
+print("֥åδƻܤƥԡޤƻOFFˤʤꡢ᡼OFFˤʤޤ<br>");
+print("ʣƤǧԽԤäƤ<br>");
+print("Υܥ򲡤ʣΥڡӤޤ<br>");
+print("</font>");
+print("ʣ֥å̾");
+echo "<select size=1 name=BNAME_1>";
+echo "<option value='$BNAME'>$BNAME";
+for($select_count = 0; $select_count < $bname_count; $select_count++){
+   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
+   }
+echo "</select>";
+print("ʣ֥å̾");
+print("<INPUT type='text' NAME=BNAME_2 size='12' value=''>");
+
+print("֥åʣΥ饤̾");
+echo "<select size=1 name=CNAME>";
+echo "<option value='$CNAME'>$CNAME";
+for($select_count = 0; $select_count < $cname_count; $select_count++){
+   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
+   }
+
+print("<input type=submit value='ʣμ¹'>");
+print("</form>");
+
+
+
+
 print("<br><br>");
 
 print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
@@ -177,6 +215,9 @@ echo "</select>";
 print("<input type=submit value='֥åư'>");
 print("</form>");
 
+
+
+
 print("<br><br>");
 
 print("<FORM METHOD=GET ACTION='block_delete.php' target='top'>");
@@ -187,7 +228,6 @@ print("֥å̾¸ߤϤʤˤԤޤ<br>");
 print("Υܥ򲡤ȰưڡӤޤ<br>");
 print("</font>");
 print("ѹ֥å̾");
-// print("<INPUT type='text' NAME=BNAME size='12' value='$BNAME'>");
 echo "<select size=1 name=BNAME>";
 echo "<option value='$BNAME'>$BNAME";
 for($select_count = 0; $select_count < $bname_count; $select_count++){
@@ -196,18 +236,14 @@ for($select_count = 0; $select_count < $bname_count; $select_count++){
 echo "</select>";
 print("ѹ֥å̾");
 print("<INPUT type='text' NAME=BNAME2 size='12' value=''>");
-// echo "<select size=1 name=BNAME2>";
-// echo "<option value=''>";
-// for($select_count = 0; $select_count < $bname_count; $select_count++){
-//    echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
-//    }
-echo "</select>";
 print("<input type=submit value='֥åư'>");
 print("</form>");
 
-print("<br><br>");
 
 
+
+print("<br><br>");
+
 print("<FORM METHOD=GET ACTION='block_newedit.php' target='top'>");
 print("<tr><td><font color=red size=3>");
 print("</td></tr>");
@@ -226,6 +262,9 @@ echo "</select>";
 print("<input type=submit value='֥å Խ'>");
 print("</form>");
 
+
+
+
 print("<br><br>");
 
 
