@@ -184,12 +184,18 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<select size=1 name=PROTO>";
    echo "<option value=$PROTO selected>$PROTO";
    echo "<option value=ICMP>ICMP";
+   echo "<option value=V6ICMP>V6ICMP";
    echo "<option value=ICMP2>ICMP2";
    echo "<option value=TRAC>TRAC";
    echo "<option value=UDP>UDP";
    echo "<option value=TCP>TCP";
+   echo "<option value=TCP6>TCP6";
    echo "<option value=URL>URL";
+   echo "<option value=URL6>URL6";
    echo "<option value=GET>GET";
+   echo "<option value=GET6>GET6";
+   echo "<option value=DEF>DEF";
+   echo "<option value=DEF6>DEF6";
    echo "<option value=SSL>SSL";
    echo "<option value=SMTP>SMTP";
    echo "<option value=FTP>FTP";
