@@ -317,12 +317,18 @@ elseif($step1 > 0 && 0 == strcmp($MONITOR, "PORT") && $step2 <= 0){
    print("<tr><td>");
    print("<select size=1 name=PROTO>");
    print("<option value=ICMP>ICMP̳ǧ");
+   print("<option value=V6ICMP>V6ICMP̳ǧ");
    print("<option value=ICMP2>ICMP̳ǧܺ");
    print("<option value=TRAC>TRAC̳ǧ");
    print("<option value=UDP>UDPݡȥå");
    print("<option value=TCP>TCPݡȥå");
+   print("<option value=TCP6>TCP6ݡȥå");
    print("<option value=URL>URLơ");
+   print("<option value=URL6>URL6ơ");
    print("<option value=GET>URLơ GET");
+   print("<option value=GET6>URLơ GET6");
+   print("<option value=DEF>SHA1ϥåͥκ");
+   print("<option value=DEF6>SHA1ϥåͥκV6");
    print("<option value=SSL>SSLURLơ");
    print("<option value=SMTP>SMTPơ");
    print("<option value=FTP>FTPơ");
@@ -486,6 +492,14 @@ elseif($step1>0 && $step2>0 && $step3>0 && $step4>0 && $step5<=0){
          print("<INPUT type='hidden' NAME=PORT size='8' value='0'>");
          print("</td></tr>");
          }
+      else if(0 == strcmp($PROTO, "V6ICMP")){
+         print("<tr><td>");
+         print("STEP5: V6ICMPݡ0\n");
+         print("</td></tr>");
+         print("<tr><td>");
+         print("<INPUT type='hidden' NAME=PORT size='8' value='0'>");
+         print("</td></tr>");
+         }
       else if(0 == strcmp($PROTO, "ICMP2")){
          print("<tr><td>");
          print("STEP5: ICMP2ݡ0\n");
