@@ -53,7 +53,7 @@ else{
    }
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -63,7 +63,7 @@ $select_data = "update errlog set sign = sign + 100 where uct > $settime $view_u
 
 print("$select_data \n");
 
-$result = pg_query($conn, $select_data);
+$result = db_query($conn, $select_data);
 if(!$result){
    print("bud query\n");
    exit;
@@ -72,8 +72,8 @@ if(!$result){
 print(" ｪλ \n");
 print("</font>");
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 </pre>
