@@ -1,6 +1,10 @@
 #!/bin/sh
 # sitar client startup script
 #
+
+ulimit -n 10000
+ulimit -s 2056
+
 PATH=$PATH:/usr/sbin:/usr/local/zither/bin
 CONF_PATH=/usr/local/zither/conf
 TMP_PATH=/usr/local/zither/tmp
