@@ -19,14 +19,11 @@ int conf_set( char *conf_filename )
 FILE * fp;
 int inA=1;
 int stat = 0;
-// char * tmp;
 
 char * chB;
 char * chC;
 
 char * chA = (char *)calloc(IP_LEN, sizeof(char));
-//char * chB = (char *)calloc(IP_LEN, sizeof(char));
-//char * chC = (char *)calloc(IP_LEN, sizeof(char));
 
 
 if((fp = fopen(conf_filename, "r"))!=NULL){
@@ -49,10 +46,6 @@ if((fp = fopen(conf_filename, "r"))!=NULL){
             chB = count_memcpy2(chB, chA, 0, (mem_tcount(chA, ':') - 1));
             chC = safe_memcpy(chC, (strchr(chA, ':') + 1), BUF_MAX);
 
-// v6 test 用コメント
-printf("chA=%s chB=%s chC=%s\n", chA, chB, chC);
-
-
             if(BUF_LEN > strlen(chC) && IP_LEN > strlen(chB)){
                rm_crlf(chC, strlen(chC));
                inA = path_check(chB);
