@@ -3,7 +3,7 @@
 #include<stdlib.h>
 #include<string.h>
 
-#include"sitar_scan.h"
+//#include"sitar_scan.h"
 #include<almemsys/almemsys.h>
 
 
