@@ -52,60 +52,125 @@
 #define SOCK_9 "оݤȰۤʤä̾ԤäƤޤ󤫡  "
 #define SOCK_10 "̾褬ॢȤޤNSʤǤ "
 #define SOCK_11 "̾褬˽ޤ "
-#define SOCK_12 "ͽ "
+#define SOCK_12 "DNS ˰۾郎褦Ǥ "
 #define SOCK_13 "getsockopt()ˤڥǥ󥰥顼μ˹Ԥʤ "
 #define SOCK_14 "ꤵ줿IPۥȤݡֹ椬¸ߤʤǽޤ "
 #define SOCK_15 "select() Ԥǥ顼ȯƤޤ "
-#define SOCK_16 "ͥ󤬥ॢȤޤ "
+#define SOCK_16 "select() ԤǥॢȤƤޤ "
 #define SOCK_17 "ѥåȤޤǤ "
 #define SOCK_18 "ݡãѥåȤϼޤǤ "
+#define SOCK_19 "顼ֹͳˤꥳͥ˼Ԥޤ "
+#define SOCK_20 "read()ˤɤ߹ߤॢȤޤ "
+#define SOCK_21 "read()κ˥ͥǤ줿⤷ޤ "
+#define SOCK_22 "read()ˤɤ߹ߤޤǤ "
+#define SOCK_23 "Υ顼ˤäƼԤƤޤ"
+#define SOCK_24 "ͥ褿֤ۤƤޤ "
+#define SOCK_25 "connect()顼֤ƼԤƤޤ "
 
-#define URL_1 "URL ֤äƤơɤ200ְʳǤ  "
+// scanssl Τߤǻ
+#define URL_1 "URL ֤äƤơɤ200300ְʳǤ  "
 #define URL_2 "URL Υǡ뤳ȤޤǤ  "
-#define URL_3 "URL Υǡ줺ॢȤޤ  "
-#define URL_4 "URL ֤äƤơɤ200Ǥ "
+#define URL_4 "եμ֤ͰǤ "
+#define URL_44 "URL ơɤ200300Ǥ "
 
-#define SMTP_1 "SMTP HELOФ֤äƤơɤ200ְʳǤ  "
-#define SMTP_11 "SMTP ³Υơɤ200ְʳǤ  "
-#define SMTP_2 "SMTP HELOФƤΥǡ뤳ȤޤǤ  "
-#define SMTP_22 "SMTP ³μǡǡ򤦤ȤޤǤ "
-#define SMTP_3 "SMTP HELOФƤǡ줺ॢȤޤ  "
-#define SMTP_33 "SMTP ³Υǡ줺ॢȤޤ  "
-#define SMTP_4 "SMTP HELOФ֤äƤơɤ200Ǥ "
-#define SMTP_44 "SMTP ³֤äƤơɤ200Ǥ "
+// scan_urlǻ
+#define URLA_1 "URL ꥯȥإå쥯Ȥ˥ॢ "
+#define URLA_2 "URL ꥯȥإå쥯Ȥ˼ "
+#define URLA_3 "URL ꥯȥإåХåե˽񤭹ʤ "
+#define URLA_33 "URL ꥯȥإå "
+#define URLA_4 "ơɤ߹ߤޤǤ "
+#define URLA_5 "ơɤ߹ߤκ˥ͥǤޤ "
+#define URLA_6 "ơɤ߹ߤ˥ॢȤƤޤ "
+#define URLA_7 "ơμ꤬ޤǤ "
+#define URLA_77 "ơμ꤬ޤ "
+#define URLA_8 "URL եΤ礭ɤ߼ͤۤƤޤ "
+#define URLA_9 "URL եΤɤ߼˼ԤƤޤ "
+#define URLA_99 "URL եΤɤ߼ޤ "
+#define URLA_01 "URL եμ֤ͤۤƤޤ "
+#define URLA_011 "URL եμ֤ͰǤ "
+#define URLA_02 "URL եμ֤ͤۤƤޤ "
+#define URLA_03 "URL ơɤ200300ǤϤޤ "
+#define URLA_033 "URL ơɤ200300Ǥ "
+#define URLA_04 "URL Ǥե뤬Խ줿ǽޤΥ顼᡼ϴܰ󤷤Фޤ "
+#define URLA_044 "URL Ǥե뤬ԽƤʤǧƤ "
+
+
+
+#define SELECT_5 "ꥯȤμ˼ԤͤǤ "
+#define SELECT_6 "ꥯȤμԤ˥ॢȤޤ "
+
+#define SEND_1 "˼Ԥޤ "
+#define SEND_2 "ޤ "
+
+
+#define SMTPA_1 "SMTP ³μǡǡ򤦤ȤޤǤ "
+#define SMTPA_2 "SMTP ³Υǡ줺ॢȤޤ  "
+#define SMTPA_3 "³μɤ߹ߤޤǤ "
+#define SMTPA_4 "³μκ˥ͥǤޤ "
+#define SMTPA_5 "³μ˥ॢȤƤޤ "
+#define SMTPA_6 "³μǡǡ򤦤ȤޤǤ "
+#define SMTPA_7 "SMTP ³ľΥơ֤ͤۤƤޤ "
+#define SMTPA_77 "SMTP ³ľΥơ֤ͰǤ "
+#define SMTPA_8 "SMTP ³Υơɤ200ְʳǤ  "
+#define SMTPA_88 "SMTP ³֤äƤơɤ200Ǥ "
+#define SMTPA_99 "SMTP ³ľΤȤ˴λ "
+#define SMTPA_01 "HELOΥ쥯Ȥ˥ॢȤƤޤ "
+#define SMTPA_02 "HELOΥ쥯Ȥ˼ԤƤޤ "
+#define SMTPA_03 "HELOХåե˽񤭹ޤ "
+#define SMTPA_04 "HELOμɤ߹ߤޤǤ "
+#define SMTPA_05 "HELOμκ˥ͥǤޤ "
+#define SMTPA_06 "HELOμ˥ॢȤƤޤ "
+#define SMTPA_07 "HELOμǡǡ򤦤ȤޤǤ "
+#define SMTPA_08  "SMTP HELOФॢȤޤ "
+#define SMTPA_088 "SMTP HELOФ֤Ǥ "
+#define SMTPA_09 "SMTP HELOФ֤äƤơɤ200ְʳǤ  "
+#define SMTPA_099 "SMTP HELOФ֤äƤơɤ200֤Ǥ "
+
+
+#define STATA_1 "쥯Ȥ۾ｪλƤޤ "
+#define STATA_2 "쥯ȤॢȤޤ "
+#define STATA_3 "³μɤ߹ߤޤǤ "
+#define STATA_4 "³μκ˥ͥǤޤ "
+#define STATA_5 "³μ˥ॢȤƤޤ "
+#define STATA_6 "ƻоݤ֤ޤ "
+#define STATA_7 "ơ˥ॢȤƤޤ "
+#define STATA_77 "ơ֤Ǥ "
+#define STATA_8 "ơޤ "
+#define STATA_9 "ơԤΤǤ "
 
-#define STAT_1 "³νʳ֤äƤͤޤ "
-#define STAT_2 "쥯Ȥ۾ｪλƤޤ "
-#define STAT_3 "쥯ȤॢȤޤ³˻֤äƤޤ "
-#define STAT_4 "ǡ礭۾Ǥ "
-#define STAT_5 "ơޤ "
-#define STAT_6 "ơԤΤǤ "
-#define STAT_7 "ƻоݤ֤ޤ "
 
 #define COM_1 "¹ԥޥɤॢȤޤ  "
 #define COM_2 "ޥɤ¹ԤǤޤǤ  "
 #define COM_3 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ "
 #define COM_4 "֤ͤƤʤǽޤ "
 
-#define ICMP_1 "RAW socket Ȥˤroot¤ɬפǤ  "
-#define ICMP_2 "ICMP ѥåȤ뤳ȤޤǤ  "
-#define ICMP_3 "recv()˽λƤޤ "
-#define ICMP_4 " ICMP ѥåȤäƤޤ  "
-#define ICMP_5 "ICMP RTT ͤäƤޤ  "
-#define ICMP_6 "ICMP RTT ͤǤ  "
-#define ICMP_16 "ICMP RTT 3ʿѤͤǤ "
-#define ICMP_17 "ICMP RTT 3ʿѤͤۤƤޤ "
-#define ICMP_7 "ICMP ѥåȤŪۥȤãǤޤǤȺǸΥ롼äƤޤ  "
-#define ICMP_8 "ICMP ѥåȤTTL0ˤʤꡢѥåȤ˴ޤ"
-#define ICMP_13 "ICMPѥåȤ뤳Ȥޤ "
-#define ICMP_14 "λˤICMPѥåȤ뤳Ȥޤ "
-#define ICMP_15 "ɸIPޤǤѥ롼ֻ֤Ƥޤ "
-#define ICMP_01 "ICMPѥåȤޤ "
-#define ICMP_02 "ѥåԤǥॢȤޤ "
-#define ICMP_03 "RTTॢȤư "
-#define ICMP_04 "ICMP_ECHO 򽦤äƤޤ "
-#define ICMP_05 "ICMP ѥåȰʳ򽦤äƤޤ "
-#define ICMP_06 "IPɥ쥹פޤ "
+
+#define ICMPA_1 "socketĤޤRAW socket Ȥˤroot¤ɬפǤ  "
+#define ICMPA_2 "ICMP ѥåȤ뤳ȤޤǤ  "
+#define ICMPA_3 "select()η֤ξ¤ۤƤޤ "
+#define ICMPA_4 "recvfrom()ԤƤޤƤޤ "
+#define ICMPA_5 "RTT ѥåȤιԤ֤ͤۤƤޤ "
+#define ICMPA_55 "RTT ѥåȤιԤ֤ͤϰǤ "
+#define ICMPA_66 "ץ饤ޤ "
+#define ICMPA_7 "ICMP ѥåȤŪۥȤãǤޤǤ "
+#define ICMPA_8 "λˤICMPѥåȤ뤳Ȥޤ "
+#define ICMPA_9 " ICMP ѥåȤäƤޤ  "
+#define ICMPA_01 "ICMPѥåȤ뤳Ȥޤ "
+
+#define UDPA_1 "UDP RAWåȤޤ "
+#define UDPA_11 "UDP RAWåȤޤ "
+#define UDPA_2 "UDP RAWåȤޤǤ "
+#define UDPA_22 "UDP RAWåȤޤ "
+#define UDPA_3 "UDP setsockeopt()˼ԤƤޤ "
+#define UDPA_4 "UDP ݡãǧѥåȤ˼ "
+#define UDPA_44 "UDP ݡãǧѥåȤ "
+#define UDPA_5 "UDPݡãΥѥåȤޤ󡢥ݡȤϳƤޤ "
+#define UDPA_6 "(ICMP_UNREACH)ݡãѥåȤޤݡȤϳƤޤ  "
+#define UDPA_7 "(ICMP_UNREACH_PORT)ݡãѥåȤޤݡȤϳƤޤ  "
+#define UDPA_8 "(ICMP_UNREACH_PORT ICMP_UNREACH) ʳΥѥåȤ򤦤ȤäƤޤޤ "
+#define UDPA_9 "UDPݡãѥåȤϼޤǤݡȤϳƤޤ "
+#define UDPA_01 "UDP ƻ뤬۾ｪλޤ "
+
 
 #define TRACE_1 "RAW socket Ȥˤroot¤ɬפǤ  "
 #define TRACE_2 "tracerouteΥѥåȤ뤳ȤޤǤ  "
@@ -176,6 +241,11 @@
 #define DHW_ERR3 "DHWϥ顼֤ޤǤ "
 #define DHW_ERR4 "DHW֤ͤ³ڤޤDHW˥ॢȤ⤷ޤ "
 
+#define DHWA_1 "DHW ޥ쥯Ȥ˥ॢ "
+#define DHWA_2 "DHW ޥ쥯Ȥ˼ "
+#define DHWA_3 "DHW ޥХåե˽񤭹ʤ "
+#define DHWA_33 "DHW ޥ "
+
 #define DB_ERR1  "DB³ΥǥߥοǤ "
 #define DB_ERR2  "DB³Υǡ礭Ǥ "
 
