@@ -29,8 +29,8 @@ gettimeofday((struct timeval *) (icmp->icmp_data), (struct timezone *) 0);
 
 icmp->icmp_type = ICMP_ECHO;
 icmp->icmp_code = 0;
-icmp->icmp_id = id;
-icmp->icmp_seq = n;
+icmp->icmp_id = htons(id);
+icmp->icmp_seq = htons(n);
 icmp->icmp_cksum =0;
 icmp->icmp_cksum = checksum((u_short *) icmp, len);
 
