@@ -34,12 +34,26 @@ for(count = 0; count <= gd.td.tcount; count++){
    if((gd.td.mutex_name[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
    }
 
+// wait name
+if((gd.td.wait_name=(char **)malloc(sizeof(char *) * (gd.td.tcount + 2)))==NULL){exit(1);}
+for(count = 0; count <= gd.td.tcount; count++){
+   if((gd.td.wait_name[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+   }
+// wait time
+if((gd.td.wait_time = (char *)calloc((gd.td.tcount + 2), sizeof(char)))==NULL){m_exit(1);}
+for(count = 0; count <= gd.td.tcount; count++){
+   gd.td.wait_time[count] = 0;
+   }
+
+
 // mid name
 if((gd.td.middle_name=(char **)malloc(sizeof(char *) * (gd.td.midcount + 2)))==NULL){exit(1);}
 if((gd.td.middle_id=(char *)malloc(sizeof(char)*(gd.td.midcount + 2)))==NULL){exit(1);}
+if((gd.td.middle_id2=(char *)malloc(sizeof(char)*(gd.td.midcount + 2)))==NULL){exit(1);}
 for(count = 0; count <= gd.td.midcount; count++){
    if((gd.td.middle_name[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
    gd.td.middle_id[count] = 0;
+   gd.td.middle_id2[count] = 0;
    }
 
 // trace buf
@@ -88,6 +102,11 @@ for(count = 0; count <= gd.td.tcount; count++){
    free(gd.td.mutex_name[count]);
    }
 
+for(count = 0; count <= gd.td.tcount; count++){
+   free(gd.td.wait_name[count]);
+   }
+free(gd.td.wait_time);
+
 for(count = 0; count <= gd.td.midcount; count++){
    free(gd.td.middle_name[count]);
    }
@@ -107,6 +126,7 @@ free(gd.td.fdstat);
 free(gd.td.mutex_name);
 free(gd.td.middle_name);
 free(gd.td.middle_id);
+free(gd.td.middle_id2);
 return 0;
 }
 
