@@ -56,6 +56,7 @@ if((fp = fopen(file_name, "r"))!=NULL){
          // 残りのメモリー領域を初期化（フォーマット）
          for(; ppp < gd.td.midcount; ppp++){
             gd.td.middle_id[ppp] = 0;
+            gd.td.middle_id2[ppp] = 0;
             gd.td.middle_name[ppp] = null_free(gd.td.middle_name[ppp]);
             }
          // ファイルを閉じて離脱 通常はこちらから離脱するはず。
@@ -86,10 +87,11 @@ if((fp = fopen(file_name, "r"))!=NULL){
             #endif
             // データをメモリーに入れていきます
             gd.td.middle_id[ppp] = id;
+            gd.td.middle_id2[ppp] = id;
             id = 0;
             gd.td.middle_name[ppp] = safe_memcpy(gd.td.middle_name[ppp], swap, BUF_LEN);
             #ifdef MINAME_BUG
-            printf("miname_install(): %d,%s\n", gd.td.middle_id[ppp], gd.td.middle_name[ppp]);
+            printf("miname_install(): %d,%d,%s\n", gd.td.middle_id[ppp], gd.td.middle_id2[ppp], gd.td.middle_name[ppp]);
             #endif
             }
          else{
