@@ -24,6 +24,11 @@
 
 char * resolvename_sk(char * backdata, char *name, int timeout, unsigned long * ret, char * dns_ip, int * stat, char type)
 {
+char str[INET6_ADDRSTRLEN];
+
+if(NULL == dns_ip){
+   dns_ip = safe_memcpy(dns_ip, "0.0.0.0", BUF_LEN);
+   }
 
 // char * scan_dns_connect(int, char *, char *, char *, int, int *);
 // backdata = scan_dns_connect(53, dns_ip, name, backdata, timeout, stat);
@@ -31,7 +36,7 @@ backdata = scan_dns_connect(53, dns_ip, name, backdata, timeout, stat, type);
 swap_mem(backdata, '\n', 0x00);
 
 #ifdef RESOLV_DEBUG
-printf("RESOLV_DEBUG: resolvname(2): resolvname %s\n", backdata);
+printf("RESOLV_DEBUG: resolvname(2): stat %d resolvname %s\n", * stat, backdata);
 #endif
 
 if(* stat < 0){
@@ -42,7 +47,15 @@ if(* stat < 0){
    }
 else{
    //  ちゃんと引けた場合
-   inet_pton(AF_INET, backdata, ret);
+   if(type == '4'){
+      inet_pton(AF_INET, backdata, ret);
+      }
+   else if(type == '6'){
+      inet_pton(AF_INET6, backdata, ret);
+      #ifdef RESOLV_DEBUG
+      printf("RESOLV_NAME: resolvname_sk IP V6 Addr = %s\n", (char *)inet_ntop(AF_INET6, ret, str, INET6_ADDRSTRLEN));
+      #endif
+      }
    backdata = safe_memcpy(backdata, SOCK_11, BUF_MAX);
    #ifdef RESOLV_DEBUG
    fprintf(stderr,"RESOLV_DEBUG: resolvname(5): %s %s\n", SOCK_11, name);
