@@ -16,6 +16,7 @@
 #include<file_comp/file_comp.h>
 
 
+// #define BLOCK_TEST_BUG
 // #define MONITOR_BUG
 
 global_data_t gd;
@@ -30,16 +31,31 @@ pthread_mutex_t udp_mutex;
 //  scan_block はポート、コマンドのスレッド分岐先の関数になります
 int main(int argc, char ** argv)
 {
-int dstat, mode, i, fds;
+int dstat, mode, i, fds, sk, stat, interval;
 char mid_stat;
+char * ip_addr;
+char * send_ip;
+char * sock_ip;
+char * senddata;
+char * backdata;
 extern char *optarg;
 
+gd.fi.command_path = safe_memcpy(gd.fi.command_path, "/usr/local/zither/sample_bin", BUF_SLEN);
+
+if((ip_addr = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((send_ip = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((sock_ip = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((backdata = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((senddata = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
 if((gd.di.dns_name = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
 gd.di.dns_name = safe_memcpy(gd.di.dns_name, "127.0.0.1", BUF_MAX);
 
 mid_stat = 0;
 dstat = 0;
 mode = 0;
+sk = 0;
+stat = 0;
+interval = 10;
 
 pthread_mutex_init(&name_mutex, NULL);
 pthread_mutex_init(&exec_mutex, NULL);
@@ -54,10 +70,10 @@ private_data_t *pd;
 if((pd = (private_data_t *)malloc(sizeof(private_data_t)))==NULL){exit(1);}
 scan_malloc_set(pd);
 
-if((fds = getdtablesize()) <= 0){
-   fprintf(stderr,"p_open(): not get fd size.\n");
-   fds = 1024;
-   }
+//if((fds = getdtablesize()) <= 0){
+//   fprintf(stderr,"p_open(): not get fd size.\n");
+//   fds = 1024;
+//   }
 
 //for(co = 0; co < COM_LEN; co++){
 //   pids[co] = (int *)malloc((u_int)(fds * sizeof(int)));
@@ -65,8 +81,9 @@ if((fds = getdtablesize()) <= 0){
 
 
 
+
 // optionの処理
-while((i=getopt(argc,argv,"a:d:r:m:v"))!= EOF){
+while((i=getopt(argc,argv,"a:d:r:m:i:t:v"))!= EOF){
    switch(i){
       case 'm': if(0 == ch_int2(optarg)){
                    mode = strtol(optarg, (char **)NULL, 10);
@@ -79,6 +96,26 @@ while((i=getopt(argc,argv,"a:d:r:m:v"))!= EOF){
                    pd->sb.swap_2 = safe_memcpy(pd->sb.swap_2, "NOT_DATA", 1024);
                    }
               break;
+      case 'i': if(optarg != NULL){
+                   ip_addr = safe_memcpy(ip_addr, optarg, 1024);
+                   }
+                else{
+                   ip_addr = safe_memcpy(ip_addr, "", 1024);
+                   }
+              break;
+      case 't': if(optarg != NULL){
+                   interval = strtol(optarg, (char **)NULL, 10);
+                   if(interval < 0){
+                      interval = 0;
+                      }
+                   else if(interval > 60){
+                      interval = 60;
+                      }
+                   }
+                else{
+                   interval = 10;
+                   }
+              break;
       case 'r': if(optarg != NULL){
                    gd.di.dns_name = safe_memcpy(gd.di.dns_name, optarg, BUF_MAX);
                    }
@@ -87,7 +124,7 @@ while((i=getopt(argc,argv,"a:d:r:m:v"))!= EOF){
                    }
               break;
 
-      default : printf("scan_block_test-%s $scan_bloc_test -d <monitor_data> -m <0-1> -r <dns ip address>\n",VERSION);
+      default : printf("scan_block_test-%s $scan_bloc_test -d <monitor_data> -m <0-1> -r <dns ip address> -i <ip addr only>\n",VERSION);
 //           for(co = 0; co < COM_LEN; co++){
 //              free(pids[co]);
 //              }
@@ -99,6 +136,148 @@ while((i=getopt(argc,argv,"a:d:r:m:v"))!= EOF){
    }
 
 
+// printf("ip_addr = %s IP_ADDR size =%d\n", ip_addr, strlen(ip_addr));
+
+
+// とにかくIPがある場合はそこに飛ばす
+// ない場合のみローカル実行する。
+// とりあえず、ここで実行することが前提できてるので、
+// ip_addr に｜がふくまれて複数ある場合は転送されるので、最初の｜
+// までを接続用に取り出して、残りは送信コマンドの最後のからむにつける。
+// IP_addrがもともと一つの場合はローカルのでの実行と判断してip_addrのサイズ
+// を0にする。
+
+
+// printf("-------------------%s--------%d---%d------------------\n", ip_addr, strlen(ip_addr), char_count(ip_addr, '-'));
+
+
+if(0 < strlen(ip_addr)){
+   if(0 < char_count(ip_addr, '-')){
+      sock_ip = delim_get(ip_addr, sock_ip, '-', &stat, 0);
+      send_ip = safe_memcpy(send_ip, ip_addr + (int)strlen(sock_ip) + 1, BUF_LEN);
+//    printf("=in -=====%s=====%s====\n", sock_ip, send_ip);
+      }
+   else{
+      sock_ip = safe_memcpy(sock_ip, ip_addr, BUF_LEN);
+//    printf("=not -=====%s=====%s====\n", sock_ip, send_ip);
+      }
+   }
+else{
+   sock_ip = safe_memcpy(sock_ip, "", 1024);
+// printf("===ip_addr not====\n");
+   }
+
+
+
+
+// IP の設定がNOT
+if(0 == strlen(sock_ip)){
+   #ifdef BLOCK_TEST_BUG
+   fprintf(stderr,"use local command.\n");
+   #endif
+   }
+// IP の設定がある場合
+else{
+   #ifdef BLOCK_TEST_BUG
+   fprintf(stderr,"use network<%s> command.\n", ip_addr);
+   #endif
+
+   memset(&gd.ip.hints, 0, sizeof(gd.ip.hints));
+
+
+   // コネクションが出来ない場合
+  // FreeBSD に問題があるので、以下の関数の中で修正しています。現在検証中。
+  if((socket_connect46select(&gd.ip.hints, sock_ip, "8899", &sk, interval)) < 0){
+//  if((socket_connect46(&gd.ip.hints, sock_ip, "8899", &sk)) < 0){
+      printf("scan_block_test: Not connection ip=<%s> port=<%d>\n", sock_ip, 8899);
+
+      scan_malloc_free(pd);
+      free(pd);
+      free(gd.di.dns_name);
+      free(ip_addr);
+      free(sock_ip);
+      free(send_ip);
+      free(backdata);
+      free(senddata);
+      exit(1);
+
+      }
+   // コネクションが出来た場合
+   else{
+      // データが送れた場合
+     
+      senddata = safe_sprintf(senddata, BUF_LEN,"%s%s\n", pd->sb.swap_2, send_ip); 
+      if((stat = socket_send(sk, senddata, interval)) > 0){
+
+         #ifdef BLOCK_TEST_BUG
+         fprintf(stderr,"OK senddata %s\n", senddata);
+         #endif
+
+         backdata = select_fdcat(sk, backdata, &stat, BUF_MAX, interval);
+
+         #ifdef BLOCK_TEST_BUG
+         fprintf(stderr,"STAT %d\n", stat);
+         #endif
+
+         // データが受け取れない 
+         if(stat < 0){
+
+            printf("scan_block_test: Not recv data. ip=<%s> port=<%d>\n", ip_addr, 8899);
+
+            scan_malloc_free(pd);
+            free(pd);
+            free(gd.di.dns_name);
+            free(ip_addr);
+      free(sock_ip);
+      free(send_ip);
+            free(backdata);
+            free(senddata);
+
+            exit(1);
+
+            }
+         // ネットワーク正常終了
+         else{
+            printf("%s", backdata);
+
+            scan_malloc_free(pd);
+            free(pd);
+            free(gd.di.dns_name);
+            free(ip_addr);
+      free(sock_ip);
+      free(send_ip);
+            free(backdata);
+            free(senddata);
+            exit(1);
+
+            }
+         }
+      // データが送れない場合
+      if(stat < 0){
+
+         printf("scan_block_test: Not send data. ip=<%s> port=<%d>\n", ip_addr, 8899);
+
+         scan_malloc_free(pd);
+         free(pd);
+         free(gd.di.dns_name);
+         free(ip_addr);
+      free(sock_ip);
+      free(send_ip);
+         free(backdata);
+         free(senddata);
+
+         exit(1);
+
+         }
+      }
+
+   fprintf(stderr,"kill network<%s>.\n", ip_addr);
+
+   }
+
+
+
+
 // 先頭からむが'#'ではない
 if('#' != pd->sb.swap_2[0]){ 
    // ','が13個
@@ -186,7 +365,7 @@ if('#' != pd->sb.swap_2[0]){
             if(0 == self_memcmp(pd->sb.ch_tool, "PORT")){
 
                if(0 == self_memcmp(pd->sb.ch_prot, "UDP")){
-                  pd->sb.ch_prot = safe_memcpy(pd->sb.ch_prot, "UDP2", BUF_LEN);
+//                pd->sb.ch_prot = safe_memcpy(pd->sb.ch_prot, "UDP2", BUF_LEN);
                   scan_port(pd);
                   }
                else if(0 == self_memcmp(pd->sb.ch_prot, "TRAC")){
