@@ -33,7 +33,7 @@ int scan_smtp_connect(int, char *, char *, int);
 /*----------------- SCAN DHW CONNECT --------------------*/
 char * scan_dhw_connect(char * comand, int port, char * url_dom, char * backdata, int timeout, int * pst)
 {
-int sk, re, ret, retval, arglen, dcount, resolv_ret;
+int sk, re, ret, retval, arglen, dcount, resolv_ret, eno;
 char ipa[IP_LEN];
 char * ip_addr = ipa;
 unsigned long resoip;
@@ -54,6 +54,7 @@ ret = -1;
 errno = 0;
 arglen = sizeof(int);
 dcount = 0;
+eno = 0;
 
 #ifdef DHW_BUG
 printf("DHW: scan_dhw_connect(1): DHW COMMAND %s\n", comand);
@@ -203,172 +204,183 @@ if(errno == EINPROGRESS){
          printf("DHW: scan_dhw_connect(10): set_request*send-- %s --\n", senddata);
          #endif 
 
-         // 非同期通信の開始
-         fcntl(sk, F_SETFL, O_NONBLOCK);
 
          // DHWコマンドの送信
-         send(sk, senddata, strlen(senddata), 0);
+         retval = socket_send(sk, senddata, timeout);
 
-         tv.tv_sec = timeout;
-         tv.tv_usec = 0;
-         while(1){
-            FD_ZERO(&rfds);
-            FD_SET(sk, &rfds);
-            retval = select(sk + 1, &rfds, NULL, NULL, &tv);
 
-            // select の異常終了
-            if(retval < 0){
-               #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(11): retval 0 ERR\n");
-               #endif 
-               backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_15);
-               // 非同期通信から同期通信に
-               fcntl(sk, F_SETFL, 0);
-               close(sk);
-               * pst = -1;
-               return backdata;
+         // select のタイムアウト
+         if(retval == -2){
+            backdata=safe_sprintf(backdata, BUF_MAX, "%s", DHWA_1);
+            #ifdef URL_BUG
+            printf("URL_BUG: scan_url(11): select timed out %s\n", backdata); 
+            #endif 
+            close(sk);
+            * pst = -1;
+            return backdata;
+            }
+         // select 異常終了
+         else if(retval == -3){
+            backdata=safe_sprintf(backdata, BUF_MAX, "%s %s", DHWA_2, strerror(eno));
+            #ifdef URL_BUG
+            printf("DHW_BUG: scan_dhw(10): select error %s\n", backdata);
+            #endif 
+            close(sk);
+            * pst = -1;
+            return backdata;
+            }
+         // select 異常終了
+         else if(retval == -4){
+            backdata=safe_sprintf(backdata, BUF_MAX, "%s", DHWA_3);
+            #ifdef URL_BUG
+            printf("DHW_BUG: scan_dhw(10): select error %s\n", backdata);
+            #endif 
+            close(sk);
+            * pst = -1;
+            return backdata;
+            }
+         // select 異常終了 その他
+         else if(retval < 0){
+            backdata=safe_sprintf(backdata, BUF_MAX, "%s %s", DHWA_2, strerror(eno));
+            #ifdef URL_BUG
+            printf("DHW_BUG: scan_dhw(10): select error %s\n", backdata);
+            #endif 
+            close(sk);
+            * pst = -1;
+            return backdata;
+            }
+         // select 正常
+         else{
+
+            backdata=safe_sprintf(backdata,BUF_MAX, "%s", DHWA_33);
+
+            dcount = socket_readasth(sk, recvdata, BUF_LEN, timeout, 0);
+
+            swap_mem(recvdata, '\t', ' ');
+            swap_mem(recvdata, ',', ' ');
+            swap_mem(recvdata, '"', ' ');
+
+            #ifdef DHW_BUG
+            printf("DHW: scan_dhw_connect(13): recv-- %s --\n", recvdata);
+            #endif
+
+            // 受信量がゼロ
+            if(dcount == 0){
+                 backdata = safe_sprintf(backdata,BUF_MAX, "%s", SOCK_22);
+               ret = -1;
+            }
+            else if(dcount == -1){
+               backdata = safe_sprintf(backdata,BUF_MAX, "%s", SOCK_21);
+               ret = -1;
                }
-            // selectのタイムアウト
-            else if(retval == 0){
-               #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(12): retval 1 ERR\n"); 
-               #endif 
-               backdata=safe_sprintf(backdata,BUF_MAX,
-                "DHW=%s IP=%s Port=%d: %s" , url_dom, ip_addr, port, SOCK_16);
-               // 非同期通信から同期通信に
-               fcntl(sk, F_SETFL, 0);
-               close(sk);
-               * pst = -1;
-               return backdata;
+            else if(dcount == -2){
+               backdata = safe_sprintf(backdata,BUF_MAX, "%s", SOCK_20);
+               ret = -1;
                }
-
-            // select 正常
+            else if(dcount < -2){
+               backdata = safe_sprintf(backdata,BUF_MAX, "%s", DHW_ERR4);
+               ret = -1;
+               }
+            // 何らかのエラーを取得した場合
             else{
-               // 非同期通信から同期通信に戻す
-               fcntl(sk, F_SETFL, 0);
-//             dcount = recv(sk, recvdata, BUF_LEN, 0);
-               dcount = socket_readas(sk, recvdata, BUF_LEN, timeout, 0);
-
-               swap_mem(recvdata, '\t', ' ');
-               swap_mem(recvdata, ',', ' ');
-               swap_mem(recvdata, '"', ' ');
-
-               #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(13): recv-- %s --\n", recvdata);
-               #endif
-
-               // 受信量がゼロ
-               if(dcount < 1){
-                  ret = -1;
-                  backdata = safe_sprintf(backdata,BUF_MAX, "%s", DHW_ERR4);
-                  #ifdef DHW_BUG
-                  printf("DHW: scan_dhw_connect(14): <%s> %d\n", backdata, ret);
-                  #endif
-                  }
-
-               // 何らかのエラーを取得した場合
-               else{
-                  // 先頭が###DHWINFOな場合
-                  if(0 == memcmp(recvdata, "###DHWINFO ", 11)){ 
-                     int an;
-                     an = 1 + (mem_tcount(recvdata, '\n'));
-                     // 改行までのサイズと受信サイズが等しいので正常終了
-                     if(dcount == an){
-                        backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
-                        rm_char(backdata, '\n');
-                        ret = 0;
-                        #ifdef DHW_BUG
-                        printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
-                          recvdata, dcount, an);
-                        #endif
-                        }
-                     // 改行のあとにまだある場合
-                     else{
-                        if(0 == memcmp(recvdata + an, "###DHWINFO ", 11)){ 
-                           int in;
-                           in = 1 + (char_point(recvdata, '\n', 2));
-                           // 改行までのサイズと受信サイズが等しいので正常終了
-                           if(dcount == in){
-                              backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
-                              rm_char(backdata, '\n');
-                              ret = 0;
-                              #ifdef DHW_BUG
-                              printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
-                                recvdata, dcount, in);
-                              #endif
-                              }
-                           else{
-                              backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + in, DHW_ERR1);
-                              rm_char(backdata, '\n');
-                              ret = -1;
-                              #ifdef DHW_BUG
-                              printf("DHW: scan_dhw_connect(15): <%d> %s\n", ret, backdata);
-                              #endif
-                              }
+               // 先頭が###DHWINFOな場合
+               if(0 == memcmp(recvdata, "###DHWINFO ", 11)){ 
+                  int an;
+                  an = 1 + (mem_tcount(recvdata, '\n'));
+                  // 改行までのサイズと受信サイズが等しいので正常終了
+                  if(dcount == an){
+                     backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
+                     rm_char(backdata, '\n');
+                     ret = 0;
+                     #ifdef DHW_BUG
+                     printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                     recvdata, dcount, an);
+                     #endif
+                     }
+                  // 改行のあとにまだある場合
+                  else{
+                     if(0 == memcmp(recvdata + an, "###DHWINFO ", 11)){ 
+                        int in;
+                        in = 1 + (char_point(recvdata, '\n', 2));
+                        // 改行までのサイズと受信サイズが等しいので正常終了
+                        if(dcount == in){
+                           backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR3);
+                           rm_char(backdata, '\n');
+                           ret = 0;
+                           #ifdef DHW_BUG
+                           printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                             recvdata, dcount, in);
+                           #endif
                            }
                         else{
-                           backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR1);
+                           backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + in, DHW_ERR1);
                            rm_char(backdata, '\n');
                            ret = -1;
                            #ifdef DHW_BUG
-                           printf("DHW: scan_dhw_connect(16): <%d> %s\n", ret, backdata);
+                           printf("DHW: scan_dhw_connect(15): <%d> %s\n", ret, backdata);
                            #endif
                            }
                         }
-                     }
-
-                  // 先頭が###DHWINFOでないのでダメ
-                  else{
-                     int an;
-                     an = 1 + (mem_tcount(recvdata, '\n'));
-
-                     if(dcount == an){
-                        backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR2);
-                        rm_char(backdata, '\n');
-                        ret = -1;
-                        printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
-                          recvdata, dcount, 1 + (mem_tcount(recvdata, '\n')));
-                        }
                      else{
-                        backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR2);
+                        backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR1);
                         rm_char(backdata, '\n');
                         ret = -1;
                         #ifdef DHW_BUG
-                        printf("DHW: scan_dhw_connect(17): <%d> %s\n", ret, backdata);
+                        printf("DHW: scan_dhw_connect(16): <%d> %s\n", ret, backdata);
                         #endif
                         }
+                     }
+                  }
 
+               // 先頭が###DHWINFOでないのでダメ
+               else{
+                  int an;
+                  an = 1 + (mem_tcount(recvdata, '\n'));
+
+                  if(dcount == an){
+                     backdata = safe_sprintf(backdata, BUF_MAX,"%s", DHW_ERR2);
+                     rm_char(backdata, '\n');
+                     ret = -1;
+                     printf("DHW: scan_dhw_connect(test): <%s> dcount=%d tcount=%d\n",
+                       recvdata, dcount, 1 + (mem_tcount(recvdata, '\n')));
+                     }
+                  else{
+                     backdata = safe_sprintf(backdata, BUF_MAX,"RETURN=%s : %s", recvdata + an, DHW_ERR2);
+                     rm_char(backdata, '\n');
+                     ret = -1;
+                     #ifdef DHW_BUG
+                     printf("DHW: scan_dhw_connect(17): <%d> %s\n", ret, backdata);
+                     #endif
                      }
 
                   }
 
-               #ifdef DHW_BUG
-               printf("DHW: scan_dhw_connect(18): %d <2> %s\n", ret, backdata);
-               #endif
-
-               // 非同期通信から同期通信に戻す
-           //  fcntl(sk, F_SETFL, 0);
-               close(sk);
-               * pst = ret;
-               return backdata;
                }
-            }
 
-         // 非同期通信から同期通信に戻す
-         fcntl(sk, F_SETFL, 0);
-         close(sk);
-         * pst = ret;
-         return backdata;
+            #ifdef DHW_BUG
+            printf("DHW: scan_dhw_connect(18): %d <2> %s\n", ret, backdata);
+            #endif
+
+            // 非同期通信から同期通信に戻す
+        //  fcntl(sk, F_SETFL, 0);
+            close(sk);
+            * pst = ret;
+            return backdata;
+            }
          }
+
+      // 非同期通信から同期通信に戻す
+      fcntl(sk, F_SETFL, 0);
+      close(sk);
+      * pst = ret;
+      return backdata;
       }
    }
 
-
-// HOST IP 等が存在すらしない場合の処理
-
 // 非同期通信から同期通信
 fcntl(sk, F_SETFL, 0);
-backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d: %s", url_dom, ip_addr, port, SOCK_14);
+backdata=safe_sprintf(backdata,BUF_MAX, "DHW=%s IP=%s Port=%d errno=%d: %s", url_dom, ip_addr, port, errno, SOCK_19);
+
 #ifdef DHW_BUG
 printf("DHW: scan_dhw_connect(19): not connection last out\n");
 #endif
