@@ -24,11 +24,14 @@ int inB;
 int out;
 int by;
 
+float fld;
+
 ret = -1;
 inA = 0;
 inB = 0;
 out = 1;
 by = 100; // ICMPのしきい値が1の場合、10msec (0.1秒)
+fld =0.0;
 // by = 10; // ICMPのしきい値が1の場合、10msec (0.01秒)
 
 
@@ -57,31 +60,22 @@ else if((self_memcmp(pd->sb.ch_prot, "TRAC")) == 0){
       }
    }
 
-else if((self_memcmp(pd->sb.ch_prot, "TRAC2")) == 0){
-
-   pd->sb.ch_info=scan_traceudp2setopt(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); 
-
-   if(0 == (int)strlen(pd->sb.ch_info)){
-      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
-      }
-   }
-
 else if((self_memcmp(pd->sb.ch_prot, "ICMP")) == 0){
-
-   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); // 1回め
-   usleep(100000);
-   pd->sb.ch_info=scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); // 2回め
-
+   pd->sb.ch_info=scan_icmpav(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3, 10, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
-
+else if((self_memcmp(pd->sb.ch_prot, "V6ICMP")) == 0){
+   pd->sb.ch_info=scan_icmpav(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3, 10, 6);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+// 過去のICMP2の互換、現在はICMPと同じもの
 else if((self_memcmp(pd->sb.ch_prot, "ICMP2")) == 0){
-
-   pd->sb.ch_info=scan_icmp2(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3); 
-
+   pd->sb.ch_info=scan_icmpav(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3, 10, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
@@ -90,19 +84,85 @@ else if((self_memcmp(pd->sb.ch_prot, "ICMP2")) == 0){
 
 
 else if((self_memcmp(pd->sb.ch_prot,"URL")) == 0){
-   pd->sb.ch_info=scan_url_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, 0);
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 4, 0, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"GET")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 4, 1, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"DEF")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 4, 3, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"OPT")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 4, 2, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"URL6")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 6, 0, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"GET6")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 6, 1, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"DEF6")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 6, 3, pd->sb.ch_free3);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"OPT6")) == 0){
+   pd->sb.ch_info=scan_urlav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 6, 2, pd->sb.ch_free3);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
-else if((self_memcmp(pd->sb.ch_prot,"GET")) == 0){
-   pd->sb.ch_info=scan_url_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret, 1);
-   if(0 == (int)strlen(pd->sb.ch_info)){
-      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+
+else if((self_memcmp(pd->sb.ch_prot,"SSL6")) == 0){
+   //  1209600 = 2週間の秒　証明証が安全に更新出来る時間
+   time_t lim;
+   if(0 <= ch_int2(pd->sb.ch_com)){
+      lim = (86400 * strtol(pd->sb.ch_com, (char **)NULL, 10));
       }
+   else{
+      lim = 1209600;
+      }
+   #ifdef SSL_BUG
+   printf("SSL_BUG: scan_ssl_connect(x509): limit time = %ld\n", lim);
+   #endif
+
+   pd->sb.ch_info=scan_ssl_command(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, lim, &ret, pd->sb.ch_plai, 6);
+
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      if(ret > -1){
+         pd->sb.ch_info=safe_sprintf(pd->sb.ch_info, BUF_MAX,"port=%d host_data=%s: %s\n", pd->sb.port, pd->sb.ch_host, HTTPS_1);
+         }
+      else{
+         pd->sb.ch_info=safe_sprintf(pd->sb.ch_info, BUF_MAX,"port=%d host_data=%s: %s\n", pd->sb.port, pd->sb.ch_host, HTTPS_2);
+         }
+      }
+   #ifdef SSL_BUG
+   printf("SSL_BUG: scan_ssl_connect(): %d, %s, <%s>, %d, %d, %d, %s\n"
+     ,pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, lim, ret, pd->sb.ch_plai);
+   #endif
    }
 
+
 else if((self_memcmp(pd->sb.ch_prot,"SSL")) == 0){
    //  1209600 = 2週間の秒　証明証が安全に更新出来る時間
    time_t lim;
@@ -116,7 +176,7 @@ else if((self_memcmp(pd->sb.ch_prot,"SSL")) == 0){
    printf("SSL_BUG: scan_ssl_connect(x509): limit time = %ld\n", lim);
    #endif
 
-   pd->sb.ch_info=scan_ssl_command(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, lim, &ret, pd->sb.ch_plai);
+   pd->sb.ch_info=scan_ssl_command(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, lim, &ret, pd->sb.ch_plai, 4);
 
    if(0 == (int)strlen(pd->sb.ch_info)){
       if(ret > -1){
@@ -216,28 +276,52 @@ else if((self_memcmp(pd->sb.ch_prot,"PGSQL")) == 0){
 
 
 else if((self_memcmp(pd->sb.ch_prot,"SMTP")) == 0){
-   pd->sb.ch_info = scan_smtp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info,pd->sb.timeout,&ret);
+   pd->sb.ch_info = scan_smtpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 4);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+else if((self_memcmp(pd->sb.ch_prot,"SMTP6")) == 0){
+   pd->sb.ch_info = scan_smtpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), 5, 6);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
 else if((self_memcmp(pd->sb.ch_prot,"FTP")) == 0){
-   pd->sb.ch_info = scan_stat_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, "220", 3, pd->sb.timeout, &ret);
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "220", 3, (by * 10), 5, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
-
 else if((self_memcmp(pd->sb.ch_prot,"POP")) == 0){
-   pd->sb.ch_info = scan_stat_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, "+OK", 3, pd->sb.timeout, &ret);
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "+OK", 3, (by * 10), 5, 4);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"SSH")) == 0){
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "SSH", 3, (by * 10), 5, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
-else if((self_memcmp(pd->sb.ch_prot,"SSH")) == 0){
-   pd->sb.ch_info = scan_stat_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, "SSH", 3, pd->sb.timeout, &ret);
+else if((self_memcmp(pd->sb.ch_prot,"FTP6")) == 0){
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "220", 3, (by * 10), 5, 6);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"POP6")) == 0){
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "+OK", 3, (by * 10), 5, 6);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+else if((self_memcmp(pd->sb.ch_prot,"SSH6")) == 0){
+   pd->sb.ch_info = scan_statav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, "SSH", 3, (by * 10), 5, 6);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
@@ -251,69 +335,31 @@ else if((self_memcmp(pd->sb.ch_prot,"DHW")) == 0){
    }
 
 else if((self_memcmp(pd->sb.ch_prot, "TCP")) == 0){
-   pd->sb.ch_info=scan_tcp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &ret);
+   pd->sb.ch_info=scan_tcpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), pd->sb.ch_free3, 5, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
 
-
-
-
+else if((self_memcmp(pd->sb.ch_prot, "TCP6")) == 0){
+   pd->sb.ch_info=scan_tcpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, (by * 10), pd->sb.ch_free3, 5, 6);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
 
 else if((self_memcmp(pd->sb.ch_prot, "UDP")) == 0){
-
-   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by, pd->sb.ch_free3); // 1回め
-   usleep(100000);
-   pd->sb.ch_info = scan_icmp(pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inA, by, pd->sb.ch_free3); // 2回め
-
-   pd->sb.ch_info = scan_udp_connect(pd->sb.port, pd->sb.ch_host, pd->sb.ch_info, pd->sb.timeout, &inB, pd->sb.ch_free3);
-
-   if(inA == 0 && inB == 0){
-      ret = 0;
-      }
-
-   else if(inA != 0 && inB == 0){
-      ret = -3;
-      #ifdef SCAN_PORT_DEBUG
-      fprintf(stderr,"SCAN_PORT: scan_port(): %s non icmp support or not server\n", pd->sb.ch_host);
-      #endif
-      pd->sb.ch_info = safe_sprintf(pd->sb.ch_info, BUF_MAX, "%s %s. ", pd->sb.ch_host, "non icmp suppot or not server.");
-      }
-
-   else if(inA != 0 && inB != 0){
-      ret = -2;
-      #ifdef SCAN_PORT_DEBUG
-      fprintf(stderr,"SCAN_PORT: scan_port(): %s is not server\n", pd->sb.ch_host);
-      #endif
-      }
-
-   else if(inA == 0 && inB != 0){
-      ret = -1;
-      #ifdef SCAN_PORT_DEBUG
-      fprintf(stderr,"SCAN_PORT: scan_port(): %s is icmp support ok. bat <port=%d> is not open\n",
-      pd->sb.ch_host, pd->sb.port);
-      #endif
-      }
-
-   else{
-      ret = -1;
-      #ifdef SCAN_PORT_DEBUG
-      fprintf(stderr,"SCAN_PORT: scan_port(): %s <port=%d> not support ???\n",
-      pd->sb.ch_host, pd->sb.port);
-      #endif
-      }
-
+   pd->sb.ch_info = scan_udpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3, 10, 4);
    if(0 == (int)strlen(pd->sb.ch_info)){
       pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
       }
    }
-
-
-
-else{
-   ret = -1;
-   pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"not support protocoll.\n",BUF_MAX);
+// 実装されてない
+else if((self_memcmp(pd->sb.ch_prot, "UDP6")) == 0){
+   pd->sb.ch_info = scan_udpav(pd->sb.ch_host, pd->sb.port, pd->sb.ch_info, pd->sb.timeout, &ret, by, pd->sb.ch_free3, 10, 6);
+   if(0 == (int)strlen(pd->sb.ch_info)){
+      pd->sb.ch_info=safe_memcpy(pd->sb.ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
    }
 
 
