@@ -101,7 +101,7 @@ struct packet_udp {
 struct packet_udp sendpacket;
 
 int send_sk, recv_sk, hlen, hlen1, i, co, ttl, readc, ffreadc, con, cco, repo, ttlc, chklen, len;
-int port_id, port, ports, portd, port_base, id, retport;
+int port, ports, portd, port_base, retport, in_id;
 float rtt, rtttimeout, rtta, frttt;
 float frtt[3];
 
@@ -183,7 +183,8 @@ portd = 0;
 port_base = make_counts();
 port = port_base + 33434;
 
-retport = (33500 + strtol(chid, (char **)NULL, 10));
+in_id = strtol(chid, (char **)NULL, 10);
+retport = (33500 + in_id);
 
 memset((char *)&send_addr, 0, sizeof(struct sockaddr_in));
 
