@@ -12,6 +12,7 @@
 #include<netinet/ip.h>
 #include<arpa/inet.h>
 #include<fcntl.h>
+#include<pthread.h>
 
 #include<sys/stat.h>
 #include<errno.h>
@@ -37,10 +38,231 @@
 
 // DE BUG 用
 // #define SSL_BUG
+// #define SSL_READ_BUG
+
+
+// SSL_CONNECT 排他処理
+pthread_mutex_t ssl_mutex;
+char gb_mu;
+int gb_ret;
+
+
+int ssl_connect_th(SSL * ssl)
+{
+/* SSL でコネクト、TCPではすでに確立しているが、ここではSSLでの話 */
+SSL_set_connect_state(ssl);
+gb_ret = SSL_connect(ssl);
+
+safe_pthread_mutex_lock(&ssl_mutex);
+gb_mu = 1;
+pthread_mutex_unlock(&ssl_mutex);
+
+return 0;
+}
+
+
+
+int ssl_check_th(int * timeout)
+{
+int co;
+for(co = 0; co < (int)timeout; co++){
+   safe_pthread_mutex_lock(&ssl_mutex);
+   if(gb_mu == 1){
+      pthread_mutex_unlock(&ssl_mutex);
+      break;
+      }
+   pthread_mutex_unlock(&ssl_mutex);
+   sleep(1);
+   }
+return 0;
+}
+
+
+// read() timeout 
+struct th_sslstr {
+  pthread_t t1;
+  pthread_t t2;
+  pthread_mutex_t read_mutex;
+  int th_sk;
+  int th_timeout;
+  int th_out;
+  int th_stat;
+  int th_ret;
+  int th_max;
+  char * th_chp;
+  SSL * th_ssl;
+  } th_ssl;
+
+struct th_sslstr * th_struct;
+
+
+// t1
+int sslread_check_th(void)
+{
+int co;
+co = 0;
+th_struct->t1 = pthread_self();
+
+for(; th_struct->th_out < th_struct->th_timeout; ){
+
+//   printf("---- out = %d\n", th_struct->th_out);
+
+   usleep(1000);
+   co++;
+   if( co >= 1000 ){
+      th_struct->th_out++;
+      co = 0;
+      }
+
+   safe_pthread_mutex_lock(&th_struct->read_mutex);
+   if(1 == th_struct->th_ret){
+      pthread_mutex_unlock(&th_struct->read_mutex);
+      break;
+      }
+   pthread_mutex_unlock(&th_struct->read_mutex);
+
+   if(th_struct->th_out >= th_struct->th_timeout){
+
+      safe_pthread_mutex_lock(&th_struct->read_mutex);
+      th_struct->th_ret = -1;
+      pthread_mutex_unlock(&th_struct->read_mutex);
+
+//      printf("---CLOSE--- out = %d\n", th_struct->th_out);
+
+      close(th_struct->th_sk);
+      break;
+      }
+   }
+
+return 0;
+}
+
+
+
+// t2
+int sslread_get_th(void)
+{
+int stat;
+
+stat = SSL_read(th_struct->th_ssl, th_struct->th_chp, th_struct->th_max);
+th_struct->th_stat = stat;
+
+// CLOSEされてない場合はret = 1
+safe_pthread_mutex_lock(&th_struct->read_mutex);
+if(th_struct->th_ret == -1){
+   th_struct->th_stat = -2;
+   }
+else{
+   th_struct->th_ret = 1;
+   }
+pthread_mutex_unlock(&th_struct->read_mutex);
+
+return 0;
+}
+
+
+
+int ssl_read_timeout(SSL * ssl, char * recvdata, int interval, int maxc)
+{
+
+int fd, tret;
+struct timeval tv;
+int retval;
+int ret;
+fd_set rfds;
+
+memset(&th_ssl, 0x00, sizeof(th_ssl));
+th_struct = &th_ssl;
+
+// SSL 構造体からselect()用にFDを取り出す
+fd = SSL_get_fd(ssl);
+
+th_struct->th_ret = 0;
+th_struct->th_out = 0;
+th_struct->th_sk = fd;
+th_struct->th_timeout = interval;
+th_struct->th_chp = recvdata;
+th_struct->th_max = maxc;
+th_struct->th_ssl = ssl;
+tret = 0;
+
+tv.tv_sec = interval;
+tv.tv_usec = 0;
+ret = 0;
+
+#ifdef SSL_READ_BUG
+printf("SSL_READ_BUG: ssl_read_timeout(1): interval time set %d\n", interval);
+#endif
+
+while(1){
+   FD_ZERO(&rfds);
+   FD_SET(fd, &rfds);
+   retval = select(fd + 1, &rfds, NULL, NULL, &tv);
+   if(retval < 0){
+      #ifdef SSL_READ_BUG
+      printf("SSL_READ_BUG: ssl_read_timeout(2): NG select <%d> ERRNO: %d %s\n",
+        retval, errno, strerror(errno));
+      #endif
+      ret = -1;
+      break;
+      }
+   if(retval == 0){
+      #ifdef SSL_READ_BUG
+      printf("SSL_READ_BUG: ssl_read_timeout(3): NG select <%d> ERRNO: %d %s\n",
+        retval, errno, strerror(errno));
+      #endif
+      ret = -1;
+      break;
+      }
+   if(retval >= 1){
+//      ret = SSL_read(ssl, recvdata, maxc);
+      #ifdef SSL_READ_BUG
+      printf("SSL_READ_BUG: ssl_read_timeout(4): select break <%d> ERRNO: %d %s : %s\n",
+        retval, errno, strerror(errno), recvdata);
+      #endif
+
+      pthread_mutex_init(&th_struct->read_mutex, NULL);
+
+      th_struct->th_stat = 1024;
+      if((tret = pthread_create(&th_struct->t1, NULL, (void *)sslread_check_th, NULL)) != 0){
+         fprintf(stderr,"scanssl.c pthread_create(1): %d %d\n",tret, errno);
+         }
+      if((tret = pthread_create(&th_struct->t2, NULL, (void *)sslread_get_th, NULL)) != 0){
+         fprintf(stderr,"scanssl.c pthread_create(1): %d %d\n",tret, errno);
+         }
+
+      pthread_join( th_struct->t1, NULL);
+      pthread_join( th_struct->t2, NULL);
+
+      pthread_mutex_destroy(&th_struct->read_mutex);
+
+      ret = th_struct->th_stat;
+
+      break;
+      }
+   } /* while */
+
+return(ret);
+}
+
+
+
+
+
+
+
+
+
+
+
+
 
 int main(int argc, char * argv[])
 {
-int sk, re, stat, ret, retval, dcount, arglen, sslerr, i;
+pthread_t t1;
+pthread_t t2;
+
+int sk, re, stat, ret, tret, retval, dcount, arglen, sslerr, i, mode;
 unsigned long resoip;
 char ipa[IP_LEN];
 char dom[BUF_URL];
@@ -71,6 +293,14 @@ char * url_data;
 char * dns_data; 
 int resolv_ret;
 
+double dtv1;
+double dtv2;
+float tcp_rtt;
+
+double rdtv1;
+double rdtv2;
+float get_rtt;
+
 time_t B_time, A_time, N_time, Na_time;
 B_time =0; A_time =0; N_time =0;
 ASN1_TIME * notBefore;
@@ -87,12 +317,18 @@ cert_length = 0;
 dcount = 0;
 arglen = sizeof(int);
 ret = -1;
+tret = -1;
 errno = 0;
 sslerr = 0;
 port = 0;
 timeout = 0;
 cert_lim = 0;
 resolv_ret = 0;
+mode = 0;
+
+pthread_mutex_init(&ssl_mutex, NULL);
+gb_mu = 0;
+gb_ret = -1;
 
 if((senddata = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
 if((url_data = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
@@ -109,7 +345,7 @@ memset(url_pass, 0x00, BUF_URL);
 dns_data = safe_memcpy(dns_data, "127.0.0.1", 1024);
 
 // optionの処理
-while((i=getopt(argc,argv,"a:p:t:c:u:v:d:z"))!= EOF){
+while((i=getopt(argc,argv,"a:p:t:c:u:v:d:m:z"))!= EOF){
    switch(i){
       case 'p': if(0 == ch_int2(optarg)){
                    port = strtol(optarg, (char **)NULL, 10);
@@ -119,6 +355,10 @@ while((i=getopt(argc,argv,"a:p:t:c:u:v:d:z"))!= EOF){
                    timeout = strtol(optarg, (char **)NULL, 10);
                    }
               break;
+      case 'm': if(0 == ch_int2(optarg)){
+                   mode = strtol(optarg, (char **)NULL, 10);
+                   }
+              break;
       case 'c': if(0 == ch_int2(optarg)){
                    cert_lim = (long int)strtol(optarg, (char **)NULL, 10);
                    }
@@ -138,7 +378,7 @@ while((i=getopt(argc,argv,"a:p:t:c:u:v:d:z"))!= EOF){
                    }
               break;
 
-      default : printf("scanssl-%s $scanssl -d <DNS IP> -p <port> -t <timout> -c <cert time limmit> -u <https://URL>\n",VERSION);
+      default : printf("scanssl-%s $scanssl -d <DNS IP> -p <port> -t <timout> -c <cert time limmit> -u <https://URL> -m <print mode>\n",VERSION);
               free(senddata);
               free(url_data);
               free(dns_data);
@@ -179,9 +419,10 @@ my_addr.sin_port = htons(port);
 // my_addr.sin_addr.s_addr = resoip;
 
 backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, dns_data, &resolv_ret, '4');
+
 if(resolv_ret < 0){
    // 名前解決出来ないので離脱
-   printf("DNS %s: URL %s: %s\n", dns_data, url_dom, SOCK_2);
+   printf("DNS %s: URL %s: %s\n", dns_data, url_dom, SOCK_12);
    #ifdef SSL_BUG
    fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> <%s> <%s>\n", url_dom, backdata, dns_data);
    #endif
@@ -192,6 +433,8 @@ if(resolv_ret < 0){
    exit(1);
    }
 
+
+
 my_addr.sin_addr.s_addr = resoip;
 
 
@@ -218,6 +461,9 @@ ip_addr = (char *)inet_ntop(AF_INET, &my_addr.sin_addr, buff, IP_LEN);
 printf("SSL_BUG: scanssl(3): %s\n", ip_addr);
 #endif
 
+// スタート時間をセット
+dtv1 = gettimeofday_se();
+
 // 非同期通信の開始 TCP ポートにコネ串ょん
 fcntl(sk, F_SETFL, O_NONBLOCK);
 re = connect(sk, (struct sockaddr *)(long)&my_addr, sizeof(my_addr));
@@ -226,6 +472,8 @@ re = connect(sk, (struct sockaddr *)(long)&my_addr, sizeof(my_addr));
 if(re >= 0){
    // 非同期通信から同期通信に
    fcntl(sk, F_SETFL, 0);
+   dtv2 = gettimeofday_se();
+   tcp_rtt = (dtv2 - dtv1) * 1000;
    #ifdef SSL_BUG
    printf("SSL_BUG: scan_url_connect(4): CONNECT SUCCESS %s\n", backdata);
    #endif
@@ -259,7 +507,9 @@ if(errno == EINPROGRESS){
 
       // select のタイムアウト
       else if(retval == 0){
-         printf("URL %s: Port %d: %s\n", url_data, port, SOCK_16);
+         dtv2 = gettimeofday_se();
+         tcp_rtt = (dtv2 - dtv1) * 1000;
+         printf("URL %s: Port %d: connect time=%7.4fms  %s\n", url_data, port, tcp_rtt, SOCK_16);
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(5): select time out BREAK- %d - %s\n", retval, backdata);
          #endif
@@ -275,6 +525,8 @@ if(errno == EINPROGRESS){
          }
       // 時間内に接続出来たのでLoopOUTします
       else{
+         dtv2 = gettimeofday_se();
+         tcp_rtt = (dtv2 - dtv1) * 1000;
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(6): select time succes BREAK-%d- %s\n", retval, backdata);
          #endif
@@ -305,7 +557,10 @@ if(errno == EINPROGRESS){
    else{
       // エラーがある場合
       if(retval){
-         printf("URL %s: Port %d: %s: %s\n", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
+
+         printf("URL %s: Port %d: %s: %s\n", url_data, port, SOCK_23, (retval != 0) ? strerror(retval): "0");
+
+//       printf("URL %s: Port %d: %s: %s\n", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(8): 1 SO_ERROR %d %s\n", retval, backdata);
          #endif
@@ -395,7 +650,42 @@ if(errno == EINPROGRESS){
 
 
          /* SSL でコネクト、TCPではすでに確立しているが、ここではSSLでの話 */
-         ret = SSL_connect(ssl);
+
+         if((tret = pthread_create( &t1, NULL, (void *)ssl_connect_th, (long int *)ssl)) != 0){
+            fprintf(stderr,"scanssl.c pthread_create(0): %d %d\n",tret, errno);
+            }
+         if((tret = pthread_create( &t2, NULL, (void *)ssl_check_th, (long int *)timeout)) != 0){
+            fprintf(stderr,"scanssl.c pthread_create(1): %d %d\n",tret, errno);
+            }
+
+          pthread_join( t2, NULL);
+
+          safe_pthread_mutex_lock(&ssl_mutex);
+          if(gb_mu == 0){
+             pthread_mutex_unlock(&ssl_mutex);
+             sslerr = SSL_get_error(ssl, ret);
+             ERR_error_string(sslerr, swapdata);
+             printf("URL %s: Port %d: connect time=%7.4fms: %s %s\n", url_data, port, tcp_rtt, swapdata, "SSL handshake err.");
+             #ifdef SSL_BUG
+             printf("SSL_BUG: scanssl(): SSL_connect() handshake failed: %d %s\n",ret, swapdata);
+             #endif
+             SSL_shutdown(ssl); 
+             SSL_free(ssl);
+             SSL_CTX_free(ctx);
+             ERR_free_strings();
+             close(sk);
+             free(senddata);
+             free(url_data);
+             free(dns_data);
+             free(backdata);
+             exit(1);
+             }
+          pthread_mutex_unlock(&ssl_mutex);
+
+          pthread_join( t1, NULL);
+
+          ret = gb_ret;
+
 
          if( ret != 1 ){
             sslerr = SSL_get_error(ssl, ret);
@@ -677,7 +967,9 @@ if(errno == EINPROGRESS){
 
          backdata=safe_sprintf(backdata,BUF_MAX, "URL %s: Port %d: %s", url_data, port, SOCK_3);
 
-         senddata = set_request(senddata, url_dom, url_pass);
+
+         self_set_request(senddata, url_dom, url_pass, BUF_LEN, "HEAD");
+
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(9): set_request*send-%s- %s\n", senddata, backdata);
          #endif
@@ -685,6 +977,9 @@ if(errno == EINPROGRESS){
          // 再度非同期通信の開始  SSL にした場合にFDはこれ使っていいのかな？？？
          fcntl(sk, F_SETFL, O_NONBLOCK);
 
+         // スタート時間をセット
+         rdtv1 = gettimeofday_se();
+
          // HEAD メソッドの送信 SSL専用の関数を使用。
          ret = SSL_write(ssl, senddata, strlen(senddata));
 
@@ -696,7 +991,7 @@ if(errno == EINPROGRESS){
             retval = select(sk + 1, &rfds, NULL, NULL, &tv);
             // select 異常終了
             if(retval < 0){
-               printf("URL %s: Port %d: %s: %s\n", url_data, port, SOCK_15, URL_2);
+               printf("URL %s: Port %d: %s: %s\n", url_data, port, SOCK_15, SELECT_5);
                #ifdef SSL_BUG
                printf("SSL_BUG: scanssl(10): select error %s\n", backdata);
                #endif 
@@ -716,7 +1011,9 @@ if(errno == EINPROGRESS){
                }
             // select のタイムアウト
             else if(retval == 0){
-               printf("URL %s: Port %d: %s %s\n", url_data, port, SOCK_16, URL_3);
+               rdtv2 = gettimeofday_se();
+               get_rtt = (rdtv2 - rdtv1) * 1000;
+               printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s %s\n", url_data, port, tcp_rtt, get_rtt, SOCK_16, SELECT_6);
                #ifdef SSL_BUG
                printf("SSL_BUG: scanssl(11): select timed out %s\n", backdata); 
                #endif 
@@ -735,14 +1032,69 @@ if(errno == EINPROGRESS){
                exit(1);
                }
             else{
+
+
+
+
                // 受信 SSL専用の関数を使用。
-               dcount = SSL_read(ssl, recvdata, (256-1));
+               // dcount = SSL_read(ssl, recvdata, (256-1));
+               dcount = ssl_read_timeout(ssl, recvdata, timeout, (256-1));
                recvdata[dcount] = 0x00;
 
+               rdtv2 = gettimeofday_se();
+               get_rtt = (rdtv2 - rdtv1) * 1000;
 
                // 受信量が異常
-               if(dcount < 1){
-                  printf("URL %s: Port %d: %s\n", url_data, port, URL_2);
+               if(dcount == 0){
+                  printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s\n", url_data, port, tcp_rtt, get_rtt, SOCK_22);
+                  // 非同期通信から同期通信に
+                  fcntl(sk, F_SETFL, 0);
+                  // SSL回りの開放
+                  SSL_shutdown(ssl); 
+                  close(sk);
+                  SSL_free(ssl);
+                  SSL_CTX_free(ctx);
+                  ERR_free_strings();
+                  free(senddata);
+                  free(url_data);
+                  free(dns_data);
+                  free(backdata);
+                  exit(1);
+                  }
+               else if(dcount == -1){
+                  printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s\n", url_data, port, tcp_rtt, get_rtt, SOCK_21);
+                  // 非同期通信から同期通信に
+                  fcntl(sk, F_SETFL, 0);
+                  // SSL回りの開放
+                  SSL_shutdown(ssl); 
+                  close(sk);
+                  SSL_free(ssl);
+                  SSL_CTX_free(ctx);
+                  ERR_free_strings();
+                  free(senddata);
+                  free(url_data);
+                  free(dns_data);
+                  free(backdata);
+                  exit(1);
+                  }
+               else if(dcount == -2){
+                  printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s\n", url_data, port, tcp_rtt, get_rtt, SOCK_20);
+                  // 非同期通信から同期通信に
+                  fcntl(sk, F_SETFL, 0);
+                  // SSL回りの開放
+                  SSL_shutdown(ssl); 
+                  close(sk);
+                  SSL_free(ssl);
+                  SSL_CTX_free(ctx);
+                  ERR_free_strings();
+                  free(senddata);
+                  free(url_data);
+                  free(dns_data);
+                  free(backdata);
+                  exit(1);
+                  }
+               else if(dcount < -2){
+                  printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s\n", url_data, port, tcp_rtt, get_rtt, URL_2);
                   // 非同期通信から同期通信に
                   fcntl(sk, F_SETFL, 0);
                   // SSL回りの開放
@@ -765,9 +1117,9 @@ if(errno == EINPROGRESS){
                   swap_mem(ssl_senddata, ',', ' ');
 
                   if(ret < 0){
-                     printf("%s: %s\n", ssl_senddata, URL_1);
+                     printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s\n", url_data, port, tcp_rtt, get_rtt, URL_1);
                      #ifdef SSL_BUG
-                     printf("SSL_BUG: scanssl(13): url check. not 200. ret<%d> %s\n", ret,backdata);
+                     printf("SSL_BUG: scanssl(13): url check. not 200. ret<%d> %s\n", ret, backdata);
                      #endif 
                      // 非同期通信から同期通信に
                      fcntl(sk, F_SETFL, 0);
@@ -781,12 +1133,16 @@ if(errno == EINPROGRESS){
                      free(url_data);
                      free(dns_data);
                      free(backdata);
+                     free(ssl_senddata);
                      exit(1);
                      }
                   else{
+                     if(mode != 0){
+                        printf("URL %s: Port %d: connect time=%7.4fms: read time=%7.4fms %s %s\n", url_data, port, tcp_rtt, get_rtt, ssl_senddata, URL_4);
+                        }
                      backdata = safe_sprintf(backdata, BUF_MAX,"%s: %s\n", ssl_senddata, URL_4);
                      #ifdef SSL_BUG
-                     printf("SSL_BUG: scanssl(14): url check. all succesd. ret<%d> %s\n", ret, backdata);
+                     printf("SSL_BUG: scanssl(14): url check. all succesd. ret<%d> %s %d\n", ret, backdata, mode);
                      #endif 
                      }
 
@@ -826,11 +1182,10 @@ if(errno == EINPROGRESS){
       }
    }
 
-//  HOST IP が存在すらしない
 // 非同期通信
 fcntl(sk, F_SETFL, 0);
+backdata=safe_sprintf(backdata, BUF_MAX, "URL %s: Port %d errno=%d: %s", url_data, port, errno, SOCK_19);
 
-backdata=safe_sprintf(backdata,BUF_MAX, "URL %s: Port %d: %s", url_data, port, SOCK_14);
 #ifdef SSL_BUG
 printf("SSL_BUG: scanssl(14): not connection err. %s\n", backdata); 
 #endif 
