@@ -31,9 +31,16 @@ int ret;
 ret = 0;
 
 if((strlen(url_dom) + strlen(url_pass) + 128 + 115) < max){
-   sprintf(backdata,
-     "%s /%s HTTP/1.0\nHost: %s\nUser-Agent: %s(monitorring server)\nPragma: no-cache\nCache-Control: no-cache\r\n\r\n",
-     mes, url_pass, url_dom, VERSION);
+   if(0 == self_memcmp(mes, "OPTIONS")){
+      sprintf(backdata,
+        "%s * HTTP/1.0\nHost: %s\nUser-Agent: %s(monitorring server)\nPragma: no-cache\nCache-Control: no-cache\r\n\r\n",
+         mes, url_dom, VERSION);
+      }
+   else{
+      sprintf(backdata,
+        "%s /%s HTTP/1.0\nHost: %s\nUser-Agent: %s(monitorring server)\nPragma: no-cache\nCache-Control: no-cache\r\n\r\n",
+         mes, url_pass, url_dom, VERSION);
+      }
    }
 else{
    sprintf(backdata,
