@@ -33,6 +33,7 @@ pthread_mutex_t break_mutex;
 pthread_mutex_t thread_mutex;
 pthread_mutex_t trace_mutex;
 pthread_mutex_t traceport_mutex;
+pthread_mutex_t wait_mutex;
 
 // sitar main関数
 int main(int argc, char * argv[])
@@ -59,6 +60,7 @@ pthread_mutex_init(&break_mutex, NULL);
 pthread_mutex_init(&thread_mutex, NULL);
 pthread_mutex_init(&trace_mutex, NULL);
 pthread_mutex_init(&traceport_mutex, NULL);
+pthread_mutex_init(&wait_mutex, NULL);
 
 malloc_set();
 set_data();
