@@ -151,6 +151,8 @@
      struct thread_data{
         char ** mutex_name;
         char ** middle_name;
+        char ** wait_name;
+        char * wait_time;
         int tcount;
         int tbufmax;
         int midcount;
@@ -159,6 +161,7 @@
         int thread_max;
         int * fdstat;
         char * middle_id;
+        char * middle_id2;
         }td;
 
      struct my_sock{
@@ -289,10 +292,24 @@
          char * ch_free4;         /* active swap */
          char * swap_2;           /* active swap */
          char * scan_all;           /* active swap */
+         char * scan_all2;           /* active swap */
          int port;
          int timeout; 
          int check_stat;
          }sb;
+      struct set_buf{
+         char * ch_tool;          /* active swap */
+         char * ch_plai;          /* active swap */
+         char * ch_prot;          /* active swap */
+         char * ch_port;          /* active swap */
+         char * ch_timeout;       /* active swap */
+         char * ch_info;          /* active swap */
+         char * ch_data;          /* active swap */
+         char * ch_free1;         /* active swap */
+         char * ch_free2;         /* active swap */
+         char * ch_free3;         /* active swap */
+         char * ch_free4;         /* active swap */
+         }sw;
       };
 
    typedef struct swap_array swap_array_t;
