@@ -30,8 +30,16 @@ int sitar_scan(void)
 {
 FILE * fp;
 long int fdcount;
-int stat, bstat, ren, count, delmi, fdclean, fdcountstat, sleepcount, tret, thread_co, fileget_time, filestop_time;
-time_t fileget_start, fileget_stop;
+int stat, bstat, ren, count, delmi, fdclean, fdcountstat, sleepcount, tret, thread_co;
+
+time_t fileget_start, fileget_stop, thread_start, thread_stop;
+int thread_time, thread_stop_time;
+int fileget_time, fileget_stop_time;
+int total_loss_time;
+
+//  loging
+time_t t;
+struct tm tmbuf;
 
 stat = 0;
 bstat = 0;
@@ -43,10 +51,19 @@ thread_co = 0;
 tret = 0;
 errno = 0;
 
-fileget_time = 0;
 fileget_start = 0;
 fileget_stop = 0;
-filestop_time = 0;
+fileget_time = 0;
+fileget_stop_time = 0;
+
+thread_start = 0;
+thread_stop = 0;
+thread_time = 0;
+thread_stop_time = 0;
+
+total_loss_time = 0;
+
+
 
 
 
@@ -57,12 +74,16 @@ for(;;){
    #endif
 
    // スレッド生成の時間計測開始
-   fileget_start = time(NULL);
+   thread_start = time(NULL);
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: sitar_scan(): スレッド生成の時間計測開始 (%d):\n", fileget_start);
    #endif
 
 
+   // 遅延調整計算てすと(1)
+//    sleep(randdata(0, 45));
+
+
    if((fp = fopen(gd.fi.bat2_filename_2, "r+"))!=NULL){
       #ifdef SCAN_BUG
       printf("SCAN_BUG: sitar_scan(): 二次ファイルを開きました。\n");
@@ -306,31 +327,58 @@ for(;;){
 
 
    // スレッド生成時間計測終了 
-   fileget_stop = time(NULL);
+   thread_stop = time(NULL);
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: sitar_scan(): スレッド生成の時間計測終了 (%d):\n", fileget_stop);
    #endif
-   fileget_time = fileget_stop - fileget_start;
-   #ifdef BAT_DEBUG
-   printf("BAT_DEBUG: sitar_scan(): スレッド生成にかかった時間 <%d>:\n", fileget_time);
-   #endif
-   filestop_time = (int)((gd.bf.bat2_int / 3) * 2) - fileget_time;
+   thread_time = thread_stop - thread_start;
 
-   if(filestop_time >= 0){
-      // 最初のすりーぷじっこう
+
+   // 1回めのスリープの時間を計算
+   #ifdef BAT_DEBUG
+   printf("BAT_DEBUG: sitar_scan(): スレッド生成にかかった時間 <%d>:\n", thread_time);
+   #endif
+   thread_stop_time = (int)((gd.bf.bat2_int / 3) * 2) - thread_time;
+
+/*
+    時間オーバ分をトータルカウントする
+   if(thread_stop_time <= 0){
+      total_loss_time = total_loss_time + (thread_stop_time * -1);
+      }
+    最初のすりーぷじっこう
+   else if(thread_stop_time > 0){
+      if(total_loss_time >= thread_stop_time){
+         total_loss_time = total_loss_time - thread_stop_time;
+         thread_stop_time = 0;
+         }
+      else if(total_loss_time < thread_stop_time){
+         thread_stop_time = thread_stop_time - total_loss_time;
+         total_loss_time = 0;
+         }
       #ifdef BAT_DEBUG
-      printf("BAT_DEBUG: sitar_scan(): 最初のお休みを頂きます (%d):\n", filestop_time);
+      printf("BAT_DEBUG: sitar_scan(): 最初のお休みを頂きます (%d):\n", thread_stop_time);
       #endif
-      sleep(filestop_time);
+      if(thread_stop_time > 0){
+         sleep(thread_stop_time);
+         }
       }
    else{
       fprintf(stderr,"sitar_scan():  BAT2_INT value is a little. (%d):\n", gd.bf.bat2_int);
       }
+*/
+
+   if(thread_stop_time <= 0){
+      if(total_loss_time < (gd.bf.bat2_int * 2)){
+         total_loss_time = total_loss_time + (thread_stop_time * -1);
+         }
+      else{
+         fprintf(stderr,"sitar_scan(): loss time liset. 1 \n");
+         }
+      }
+   if(thread_stop_time > 0){
+      sleep(thread_stop_time);
+      }
 
-   fileget_time = 0;
-   fileget_start = 0;
-   fileget_stop = 0;
-   filestop_time = 0;
 
    #ifdef BAT_DEBUG
    printf("SCAN_BUG: sitar_scan():  最初のお休みが終わりました\n");
@@ -349,6 +397,11 @@ for(;;){
    printf("BAT_DEBUG: sitar_scan(): リストファイル読み込み時間計測開始 (%d):\n", fileget_start);
    #endif
 
+
+   // 遅延調整計算てすと(2)
+//   sleep(randdata(0, 25));
+
+
    // リストに変更があった場合の処理
    if(gd.fi.list_stat == 1){
       #ifdef BAT_DEBUG
@@ -384,33 +437,80 @@ for(;;){
    printf("BAT_DEBUG: sitar_scan(): リストファイル読み込み時間計測終了 (%d):\n", fileget_stop);
    #endif
    fileget_time = fileget_stop - fileget_start;
+
+
+   // 2回めのスリープの時間を計算
    #ifdef BAT_DEBUG
    printf("BAT_DEBUG: sitar_scan(): リストファイルの読み込みにかかった時間です <%d>:\n", fileget_time);
    #endif
-   filestop_time = (gd.bf.bat2_int / 3) - fileget_time;
+   fileget_stop_time = (gd.bf.bat2_int / 3) - fileget_time;
 
-   if(filestop_time >= 0){
-      // 二回目すりーぷじっこう
+
+   // 時間オーバ分をトータルカウントする
+   if(fileget_stop_time <= 0){
+      if(total_loss_time < (gd.bf.bat2_int * 2)){
+         total_loss_time = total_loss_time + (fileget_stop_time * -1);
+         }
+      else{
+         fprintf(stderr,"sitar_scan(): loss time liset. 2 \n");
+         }
+      }
+   // 最初のすりーぷじっこう
+   else if(fileget_stop_time > 0){
+      if(total_loss_time >= fileget_stop_time){
+         total_loss_time = total_loss_time - fileget_stop_time;
+         fileget_stop_time = 0;
+         }
+      else if(total_loss_time < fileget_stop_time){
+         fileget_stop_time = fileget_stop_time - total_loss_time;
+         total_loss_time = 0;
+         }
       #ifdef BAT_DEBUG
-      printf("BAT_DEBUG: sitar_scan(): 二回目のお休みを頂きます (%d):\n", filestop_time);
+      printf("BAT_DEBUG: sitar_scan(): 2回めのお休みを頂きます (%d):\n", fileget_stop_time);
       #endif
-      sleep(filestop_time);
+      if(fileget_stop_time > 0){
+         sleep(fileget_stop_time);
+         }
       }
    else{
       fprintf(stderr,"sitar_scan():  BAT2_INT value is a little. (%d):\n", gd.bf.bat2_int);
       }
 
-   fileget_time = 0;
+
+
+   t = time(NULL);
+   localtime_r(&t, &tmbuf);
+
+   fprintf(stderr, "sitar-scan():[%04d:%02d:%02d:%02d:%02d:%02d]: thread time = %d : sleep time1 = %d : read time = %d : sleep time2 = %d loss = %d total=%d\n",
+     tmbuf.tm_year + 1900,
+     tmbuf.tm_mon + 1,
+     tmbuf.tm_mday,
+     tmbuf.tm_hour,
+     tmbuf.tm_min,
+     tmbuf.tm_sec,
+     thread_time,
+     thread_stop_time,
+     fileget_time,
+     fileget_stop_time,
+     gd.bf.bat2_int - (thread_time + thread_stop_time + fileget_time + fileget_stop_time), total_loss_time);
+
+
    fileget_start = 0;
    fileget_stop = 0;
-   filestop_time = 0;
+   fileget_time = 0;
+   fileget_stop_time = 0;
+
+   thread_start = 0;
+   thread_stop = 0;
+   thread_time = 0;
+   thread_stop_time = 0;
+
 
    #ifdef SCAN_BUG
    printf("SCAN_BUG: sitar_scan():   2回めのお休みを頂きました \n");
    #endif
 
 
-
    // 大掃除
    safe_pthread_mutex_lock(&fdstat_mutex);
 
