@@ -6,6 +6,7 @@
   #include<sys/types.h>
 
   #include<netinet/ip_icmp.h>
+  #include<netinet/icmp6.h>
 //  #include<arpa/inet.h>
   #include<netinet/udp.h>
 
@@ -44,11 +45,12 @@
 
 
   /* --- scan_icmp.c --- */
-  char * scan_icmp(char *, char *, int, int *, int, char *);
-  char * scan_icmp2(char *, char *, int, int *, int, char *);
-  char * scan_traceudp2setopt(char *, char *, int, int *, int, char *);
+  char * scan_icmp(unsigned long, char *, int, int *, int, char *, int, float *);
+  char * scan_icmpav(char *, char *, int, int *, int, char *, int, int);
+  char * scan_v6icmp(unsigned char *, char *, int, int *, int, char *, int, float *);
   char * scan_traceudpsetopt(char *, char *, int, int *, int, char *);
   int make_icmp8_packet(struct icmp *icmp, int len, int n, int id);
+  int make_icmpv6_packet(struct icmp6_hdr *icmp6, int len, int n, int id);
   int make_udp_header(struct udphdr *udp, int port, int sport);
   int make_ip_header(struct ip * ip, int srcip, int dstip, int iplen);
 
@@ -56,23 +58,32 @@
   u_short checksum(u_short *data, int len);
 
   /* --- scan_udpportc --- */
-  char * scan_udp_connect(int , char *, char *, int, int *, char *);
+  char * scan_udpav(char * url_data, int port, char * ch_info, int timeout, int * ret, int by, char * ch_id, int comax, int fa);
+  char * scan_udp(int port, unsigned long resoip, char * backdata, int timeout, int * stat, char * chid, float * avrt);
 
   /* --- scan_tcpport.c --- */
-  char * scan_tcp_connect(int, char *, char *, int, int *);
+  char * scan_tcpav(char * url_data, int port, char * ch_info, int timeout, int * ret, int by, char * ch_id, int comax, int fa);
+  char * scan_tcp(unsigned long resoip, int port, char * backdata, int timeout, int * stat, int by, float * avrt, int mode, int * sk);
+  char * scan_tcp6(unsigned char * resoip, int port, char * backdata, int timeout, int * stat, int by, float * avrt, int mode, int * sk);
 
   /* --- scan_url_connect.c --- */
-  char * scan_url_connect(int, char *, char *, int, int *, char);
+  char * scan_urlav(char * url_data, int port, char * ch_info, int timeout, int * ret, int by, int comax, int fa, char head, char * ch_id);
+  char * scan_url(int sk, char * url_dom, char * url_pass, char * backdata, int timeout, int * pst, float * avrt, char head, char * ch_id);
+  int safe_filefdcat_tr(int, int, int);
+  int safe_filefdcat_sha(int, int, int, char *);
+  int diff_shadata(char * sha_hash, char * filename);
 
   /* --- scan_ssl_connect.c --- */
-  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *);
+  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *, int);
   int count_memcpy3(char out[], char * data, int start, int plus);
 
   char * scan_mysql_command(char * backdata, char * query, char * server, char * username, char * passwd, char * database, int port, int timeout, int * pst, char * plai);
 
 
   /* --- scan_smtpport.c --- */
-  char * scan_smtp_connect(int, char *, char *, int, int *);
+  char * scan_smtpav(char * url_data, int port, char * ch_info, int timeout, int * ret, int by, int comax, int fa);
+  char * scan_smtp(int sk, char * backdata, int timeout, int * pst, float * avrt, float * avrt2);
+//char * scan_smtp_connect(int, char *, char *, int, int *);
   char * resolvename_th(char *, char *, int, unsigned long *);
   char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *, char);
   char * out_resolvename(char *, char *, int, unsigned long *);
@@ -81,8 +92,8 @@
   char * th_resolv(char * name, char * back, int interval, int out);
 
   /* --- scan_statport.c --- */
-  char * scan_stat_connect(int, char *, char *, char *, int, int, int *);
-
+  char * scan_statav(char * url_data, int port, char * ch_info, int timeout, int * ret, char * stat, int stat_len, int by, int comax, int fa);
+  char * scan_stat(int sk, char * backdata, char * stat, int stat_len, int timeout, int * pst, float * avrt2);
 
   /* --- scan_dhwport.c --- */
   char * scan_dhw_connect(char *, int, char *, char *, int, int *);
