@@ -14,7 +14,7 @@
 
 
   /* --- scan_ssl_connect.c --- */
-  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *);
+  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *, int);
   char *  verify_ssl(char * data, SSL *ssl, int * err);
 
 #endif
