@@ -32,7 +32,7 @@ int cgstat = self_memcmp(pd->rec.user, "cgiuser");
 if(ustat == 0 && astat != 0 && cgstat != 0){ 
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
-   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data, "", gd.ms.inip_addr[pd->rec.fdno]);
+   log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data, "", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
 
@@ -44,7 +44,7 @@ else{
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "500 NG No permit.", gd.ms.inip_addr[pd->rec.fdno]);
+     "500 NG No permit.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    } 
