@@ -20,7 +20,8 @@ extern global_data_t gd;
 
 int errdata_tok(private_data_t * pd, unsigned char * ip)
 {
-int maxlen, maxdel, ret, middleno, splen, spmax;
+int maxlen, maxdel, ret, middleno, splen, spmax, midstat;
+char subno;
 char * swap = (char *)calloc(IP_LEN, sizeof(char));
 char * swapdata = (char *)calloc(IP_LEN, sizeof(char));
 char * swapsubject = (char *)calloc(IP_LEN, sizeof(char));
@@ -29,6 +30,8 @@ char * tmp;
 middleno = 0;
 spmax = 0;
 splen = 0;
+subno = 0;
+midstat = 0;
 
 swap = safe_memcpy(swap, pd->rec.data, BUF_MAX);
 maxlen = strlen(swap);
@@ -45,7 +48,7 @@ if(0 < maxdel && 13 <= maxlen){
       put_log(gd.fp.err_fd, swapdata, pd->rec.user, ip);
       pthread_mutex_unlock(&err_mutex);
       #endif
-      swapdata = mail_form(swapdata, pd, ip, &middleno);
+      swapdata = mail_form(swapdata, pd, ip, &middleno, &midstat);
 
       if(middleno == 1){
          pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_1, BUF_MAX);
@@ -53,6 +56,7 @@ if(0 < maxdel && 13 <= maxlen){
          printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
          #endif
          middleno = 0;
+         subno = 1;
          }
       else if(middleno == 2){
          pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_2, BUF_MAX);
@@ -60,6 +64,39 @@ if(0 < maxdel && 13 <= maxlen){
          printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
          #endif
          middleno = 0;
+         subno = 1;
+         }
+      else if(middleno == 3){
+         pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_3, BUF_MAX);
+         #ifdef MAIL_DEBUG
+         printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
+         #endif
+         middleno = 0;
+         subno = 2;
+         }
+      else if(middleno == 4){
+         pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_4, BUF_MAX);
+         #ifdef MAIL_DEBUG
+         printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
+         #endif
+         middleno = 0;
+         subno = 2;
+         }
+      else if(middleno == 5){
+         pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_5, BUF_MAX);
+         #ifdef MAIL_DEBUG
+         printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
+         #endif
+         middleno = 0;
+         subno = 1;
+         }
+      else if(middleno == 6){
+         pd->rec.data = safe_memcpy(pd->rec.data, MAIL_BODY_6, BUF_MAX);
+         #ifdef MAIL_DEBUG
+         printf("MAIL_BUG: errdata_tok(): CHECK2 <%s>\n", pd->rec.data);
+         #endif
+         middleno = 0;
+         subno = 2;
          }
       else{
          pd->rec.data = safe_memcpy(pd->rec.data, swapdata, BUF_MAX);
@@ -79,7 +116,7 @@ if(0 < maxdel && 13 <= maxlen){
          put_log(gd.fp.err_fd, swapdata, pd->rec.user, ip);
          pthread_mutex_unlock(&err_mutex);
          #endif
-         swapdata = mail_form(swapdata, pd, ip, &middleno);
+         swapdata = mail_form(swapdata, pd, ip, &middleno, &midstat);
 
          if((splen = (int)strlen(swapdata)) > 0 ){
             pd->rec.data = safe_strncat(pd->rec.data, swapdata, BUF_MAX);
@@ -151,8 +188,19 @@ if(2 <= spmax){
 
    if(pd->mail.in_mailonoff == 1){
       //  subject を作ります
-      swapsubject = make_subject(swapsubject, CLIENT_BODY_9, pd->rec.user_org);
-
+      if(subno == 0){
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_9, pd->rec.user_org);
+         }
+      else if(subno == 1){
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_14, pd->rec.user_org);
+         }
+      else if(subno == 2){
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_15, pd->rec.user_org);
+         }
+      else{
+         swapsubject = make_subject(swapsubject, CLIENT_BODY_9, pd->rec.user_org);
+         }
+   
       // 本文を作ります
       swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.minfo, pd->rec.data, pd->rec.tinfo); 
       swap_mem(swapdata, '\n', (char)0x01);
