@@ -118,7 +118,7 @@ for(count = 0; count < 15; count++){
                fprintf(stderr,"file_send(): file size over err. <%s>\n", filename);
                }
 
-            swap_mem(data, '\n', (char)delim, strlen(data));         // '\n'を'0x05'に置き換え
+            swap_mem(data, '\n', (char)delim);         // '\n'を'0x05'に置き換え
             data = safe_strncat(data, "\n", BUF_MAX);               // 最後に改行追加
             if(1 < (int)strlen(data)){                              // data が1より大きい場合
                * stat = socket_send(sock_fd, data, interval);       // dataを送信
