@@ -89,7 +89,7 @@ if(0 == self_memcmp(pd->rec.user, "administrator")){
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
-    pd->rec.data, "check global data struct.", gd.ms.inip_addr[pd->rec.fdno]);
+    pd->rec.data, "check global data struct.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    }
@@ -99,7 +99,7 @@ else{
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com,
-    pd->rec.data, "500 NG", gd.ms.inip_addr[pd->rec.fdno]);
+    pd->rec.data, "500 NG", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    } 
