@@ -13,8 +13,14 @@
 #ifndef _JPRETURN_H_
   #define _JPRETURN_H_
   
-#define MAIL_BODY_1 "Υ֥åϥ᡼ˡưַ⡼1ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
-#define MAIL_BODY_2 "Υ֥åϥ᡼ˡưַ⡼2ꤵƤޤ \n ⤦ĥ顼Ϣ³ߤޤ \n üߤȡˤʴƻ뤬Ԥɬפޤ\n\n\n"
+#define MAIL_BODY_1 "顼Ϣ³٤Υ᡼Ǹߤޤ \n üߤ ˤʴƻ뤬3Ϣ³ƹԤɬפޤ\n\n\n"
+#define MAIL_BODY_2 "顼Ϣ³٤Υ᡼Ǹߤޤ \n üߤ ˤʴƻ뤬1Ԥɬפޤ\n\n\n"
+
+#define MAIL_BODY_3 "ʴƻ뤬3Ϣ³١ߤƤ᡼Ƴޤ \n\n\n"
+#define MAIL_BODY_4 "ʴƻ뤬Ԥ줿١ߤƤ᡼Ƴޤ \n\n\n"
+
+#define MAIL_BODY_5 "顼¬١Υ顼᡼ޤ \n ʾ֤¬Ƚޤ \n\n\n"
+#define MAIL_BODY_6 "ʴƻ뤬Ԥ줿١ߤƤ᡼Ƴޤ \n\n\n"
 
 #define ADMIN_BODY_1 "Administratorޥzitherδѹǽޤ\n̵꤬Τ륤餫⤷ޤ\nǰΤᡢôԤ˳ǧƤߤƤ "
 
@@ -37,7 +43,7 @@
 // #define CLIENT_BODY_9 "顼¬ޤ "
 #define CLIENT_BODY_9 "ƻǥ顼¬ޤ "
 
-#define CLIENT_BODY_10 "顼¬ޤΤǡʲδƻƤǧƤ  "
+#define CLIENT_BODY_10 "ʲδƻƤǧƤ  "
 
 #define CLIENT_BODY_11 "ǡ١˽񤭹ޤƤʤǽޤ\nǧƤ\nɬפʤƵưƤ  "
 
@@ -46,6 +52,11 @@
 
 #define CLIENT_BODY_13 "ƻܤԽϰʲURLԤȤǤޤ "
 
+#define CLIENT_BODY_14 "顼᡼öߤޤ "
+#define CLIENT_BODY_15 "줷Τǥ顼᡼Ƴޤ "
+
+
+
 #define CLIENT_HEAD_1 "ƻ륯饤ȤȤ̳ǧ "
 #define CLIENT_HEAD_2 "ä٤¬ޤ \nƻ륯饤Ȥ˲٤٤ʤ \nͥåȥ˰۾郎̵ǧƤ "
 
