@@ -18,7 +18,7 @@ int life_check(private_data_t *);
 
 int life_check(private_data_t * pd)
 {
-static int lostime;
+int lostime;
 long int intime = 0;
 int count = 0;
 
