@@ -15,7 +15,7 @@
 int log_out(char *, char *, char *);
 */
 
-
+// V6 対応
 
 int log_out(int fd, char * user, char * com, char * data1, char * data2, unsigned char * chIpadd)
 {
@@ -31,12 +31,8 @@ swap_mem(data2, '\n', ' ');
 
 time_data = time_getr(time_data);
 
-outlog_data = safe_sprintf(outlog_data, BUF_MAX, "%d.%d.%d.%d [%s] user:%s com:%s in:%s out:%s\n",
-   chIpadd[0],
-   chIpadd[1],
-   chIpadd[2],
-   chIpadd[3],
-   time_data, user, com, data1, data2);
+outlog_data = safe_sprintf(outlog_data, BUF_MAX, "%s [%s] user:%s com:%s in:%s out:%s\n",
+   chIpadd, time_data, user, com, data1, data2);
 
 #ifdef DEBUG
 fprintf(stderr,"DEBUG: log_out(): %s\n", outlog_data);
