@@ -20,7 +20,7 @@
 extern global_data_t gd;
 
 
-char * mail_form(char * swap, private_data_t * pd, unsigned char * chIpadd, int * middleno)
+char * mail_form(char * swap, private_data_t * pd, unsigned char * chIpadd, int * middleno, int * midstat)
 {
 int pri, ret;
 
@@ -76,6 +76,7 @@ free2 = delim_get(swap, free2, ',', &ret, 18);
 free3 = delim_get(swap, free3, ',', &ret, 19);
 free4 = delim_get(swap, free4, ',', &ret, 20);
 
+
 #ifdef MAIL_DEBUG
 printf("MAIL_DEBUG: mail_form(): TOOL=%s STAT=%s\n", tool, stat);
 printf("MAIL_DEBUG: mail_form(): free1=%s free2=%s free3=%s free4=%s\n", free1, free2, free3, free4);
@@ -113,12 +114,33 @@ if(0 == self_memcmp(tool, "SET")){
    #endif
 
 
+// printf("---%s---\n", info);
+
+   // sitar から送られたMIDの状況で判断している
    if(0 == self_memcmp(info, "MID2")){
       * middleno = 1;
       }
-   if(0 == self_memcmp(info, "MIX2")){
+   else if(0 == self_memcmp(info, "MIX2")){
       * middleno = 2;
       }
+   else if(0 == self_memcmp(info, "MID12")){
+      * middleno = 3;
+      * midstat = 1;
+      }
+   else if(0 == self_memcmp(info, "MIX12")){
+      * middleno = 4;
+      * midstat = 1;
+      }
+   else if(0 == self_memcmp(info, "DDX1")){
+      * middleno = 5;
+      }
+   else if(0 == self_memcmp(info, "DDX12")){
+      * middleno = 6;
+      * midstat = 1;
+      }
+   else {
+      * middleno = 0;
+      }
 
    if(0 != self_memcmp(free4, "NOT") && 2 <= strlen(free4)){
       pd->mail.block = safe_memcpy(pd->mail.block, free4, BUF_LEN);
@@ -278,6 +300,22 @@ pthread_mutex_unlock(&mysql_mutex);
 #endif
 
 
+if(* midstat == 1){
+
+// printf("<<==in===%s===%d\n", stat, * midstat);
+
+   if(0 == self_memcmp(stat, "1")){
+      stat = safe_memcpy(stat, "0", BUF_LEN);
+      }
+   else if(0 == self_memcmp(stat, "0")){
+      stat = safe_memcpy(stat, "1", BUF_LEN);
+      }
+   else{
+      stat = safe_memcpy(stat, "0", BUF_LEN);
+      }
+   }
+
+// printf("===out==%s===%d>>\n", stat, * midstat);
 
 
 // メールのプライオリティー設定
