@@ -17,6 +17,7 @@
 int mail_grsend( char *, char *, char *, char *, char *);
 */
 
+// #define MAIL_GRSEND_BUG
 
 int mail_grsend_t(mail_data_t *);
 
@@ -39,6 +40,10 @@ int tret;
 errno = 0;
 tret = 0;
 
+#ifdef MAIL_GRSEND_BUG
+printf("<%s> <%s> <%s> <%s> <%s> <%s> <%s> <%s>\n", iserver, ifrom, ircptto, icc, idata, isubject, bccadd, pri );
+#endif
+
 mail_data_t * mdd;
 if((mdd = (mail_data_t *)malloc(sizeof(mail_data_t)))==NULL){exit(1);}
 mail_malloc(mdd);
