@@ -82,7 +82,7 @@ int signal_errout(void);
 /* zither_subst.c */
 
 char * check_strtol(char * data);
-char * mail_form(char *, private_data_t *, unsigned char *, int *);
+char * mail_form(char *, private_data_t *, unsigned char *, int *, int *);
 int errdata_tok(private_data_t *, unsigned char *); 
 int global_data_list(private_data_t *);
 int life_thread(private_data_t *);
