@@ -15,7 +15,7 @@
 int put_log(char *);
 */
 
-
+// V6 対応
 
 int put_log(int fd, char *data, char * user, unsigned char * chIpadd)
 {
@@ -26,11 +26,8 @@ ret = 0;
 
 swap_mem(data, '\n', ' ');
 
-putlog_data = safe_sprintf(putlog_data, BUF_MAX, "%d.%d.%d.%d,%s,%s\n",
-  chIpadd[0],
-  chIpadd[1],
-  chIpadd[2],
-  chIpadd[3],
+putlog_data = safe_sprintf(putlog_data, BUF_MAX, "%s,%s,%s\n",
+  chIpadd,
   user, data);
 
 #ifdef DEBUG
