@@ -56,7 +56,7 @@ if(ustat == 0 || astat == 0 || cgstat == 0){
    #ifdef LOG_OUT
    safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
-     "It ends by the QUIT command.", gd.ms.inip_addr[pd->rec.fdno]);
+     "It ends by the QUIT command.", (unsigned char *)gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
    #endif
    socket_send(gd.ms.sk[pd->rec.fdno], "200 OK wait close connection.\n", (pd->life.life_int + pd->life.life_los + 15));
